--[[
	Name: Titan Panel [Work Orders]
	Author: Thorinair (Thorinair - EU Ravencrest - Alliance)
	Version: 0.9.3
--]]

-- Debug
local debugEvents = false;
local debugOnShow = false;
local debugEventHandler = false;
local debugScanBuildings = false;
local debugHandleTick = false;
local debugHandleTimer = false;
local debugHandleHide = false;

-- =============
-- === STUFF ===
-- =============

-- === TIME LOCALE ===

local localeMapping = {
    ["deDE"] = {
        ["hr"] = "(%d+) Std",
        ["min"] = "(%d+) Min",
        ["sec"] = "(%d+) Sek"
    },
    ["enUS"] = {
        ["hr"] = "(%d+) hr",
        ["min"] = "(%d+) min",
        ["sec"] = "(%d+) sec"
    },
    ["esMX"] = {
        ["hr"] = "(%d+) h",
        ["min"] = "(%d+) min",
        ["sec"] = "(%d+) s"
    },
    ["frFR"] = {
        ["hr"] = "(%d+) h",
        ["min"] = "(%d+) min",
        ["sec"] = "(%d+) s"
    },
    ["itIT"] = {
        ["hr"] = "(%d+) or",
        ["min"] = "(%d+) min",
        ["sec"] = "(%d+) s"
    },
    ["koKR"] = {
        ["hr"] = "(%d+)시간",
        ["min"] = "(%d+)분",
        ["sec"] = "(%d+)초"
    },
    ["ptBR"] = {
        ["hr"] = "(%d+) h",
        ["min"] = "(%d+) m",
        ["sec"] = "(%d+) s"
    },
    ["ruRU"] = {
        ["hr"] = "(%d+) ч",
        ["min"] = "(%d+) мин",
        ["sec"] = "(%d+) сек"
    },
     ["zhCN"] = {
         ["hr"] = "(%d+)小时",
         ["min"] = "(%d+)分",
         ["sec"] = "(%d+)秒"
     },
     ["zhTW"] = {
         ["hr"] = "(%d+)小時",
         ["min"] = "(%d+)分鐘",
         ["sec"] = "(%d+)秒"
     }
}

-- === CONSTANTS ===

-- Global
local TITAN_WORK_ORDERS_VERSION = "0.9.3";
local TITAN_WORK_ORDERS_CATEGORY = "Information";

local TITAN_WORK_ORDERS_TIMER = "TitanWorkOrdersTimer";

-- === BUILDINGS ===

-- EngineeringWorks
local TITAN_ENGINEERING_WORKS_ID = "EngineeringWorks";
local TITAN_ENGINEERING_WORKS_ICON = "Interface\\ICONS\\Trade_Engineering";
local idEngineeringWorks = nil;
local visibleEngineeringWorks = false;

-- TheTannery
local TITAN_THE_TANNERY_ID = "TheTannery";
local TITAN_THE_TANNERY_ICON = "Interface\\ICONS\\INV_Misc_ArmorKit_17";
local idTheTannery = nil;
local visibleTheTannery = false;

-- AlchemyLab
local TITAN_ALCHEMY_LAB_ID = "AlchemyLab";
local TITAN_ALCHEMY_LAB_ICON = "Interface\\ICONS\\Trade_Alchemy";
local idAlchemyLab = nil;
local visibleAlchemyLab = false;

-- EnchantersStudy
local TITAN_ENCHANTERS_STUDY_ID = "EnchantersStudy";
local TITAN_ENCHANTERS_STUDY_ICON = "Interface\\ICONS\\Trade_Engraving";
local idEnchantersStudy = nil;
local visibleEnchantersStudy = false;

-- GemBoutique
local TITAN_GEM_BOUTIQUE_ID = "GemBoutique";
local TITAN_GEM_BOUTIQUE_ICON = "Interface\\ICONS\\INV_Misc_Gem_01";
local idGemBoutique = nil;
local visibleGemBoutique = false;

-- ScribesQuarters
local TITAN_SCRIBES_QUARTERS_ID = "ScribesQuarters";
local TITAN_SCRIBES_QUARTERS_ICON = "Interface\\ICONS\\INV_Inscription_Tradeskill01";
local idScribesQuarters = nil;
local visibleScribesQuarters = false;

-- TailoringEmporium
local TITAN_TAILORING_EMPORIUM_ID = "TailoringEmporium";
local TITAN_TAILORING_EMPORIUM_ICON = "Interface\\ICONS\\Trade_Tailoring";
local idTailoringEmporium = nil;
local visibleTailoringEmporium = false;

-- TheForge
local TITAN_THE_FORGE_ID = "TheForge";
local TITAN_THE_FORGE_ICON = "Interface\\ICONS\\Trade_BlackSmithing";
local idTheForge = nil;
local visibleTheForge = false;

-- Barn
local TITAN_BARN_ID = "Barn";
local TITAN_BARN_ICON = "Interface\\ICONS\\Garrison_Building_Barn";
local idBarn = nil;
local visibleBarn = false;

-- LumberMill
local TITAN_LUMBER_MILL_ID = "LumberMill";
local TITAN_LUMBER_MILL_ICON = "Interface\\ICONS\\Garrison_Building_Lumbermill";
local idLumberMill = nil;
local visibleLumberMill = false;

-- TradingPost
local TITAN_TRADING_POST_ID = "TradingPost";
local TITAN_TRADING_POST_ICON = "Interface\\ICONS\\Garrison_Building_TradingPost";
local idTradingPost = nil;
local visibleTradingPost = false;

-- DwarvenBunker
local TITAN_DWARVEN_BUNKER_ID = "DwarvenBunker";
local TITAN_DWARVEN_BUNKER_ICON = "Interface\\ICONS\\Garrison_Building_Armory";
local idDwarvenBunker = nil;
local visibleDwarvenBunker = false;

-- WarMill
local TITAN_WAR_MILL_ID = "WarMill";
local TITAN_WAR_MILL_ICON = "Interface\\ICONS\\Garrison_Building_Armory";
local idWarMill = nil;
local visibleWarMill = false;

-- HerbGarden
local TITAN_HERB_GARDEN_ID = "HerbGarden";
local TITAN_HERB_GARDEN_ICON = "Interface\\ICONS\\INV_Misc_Herb_SansamRoot";
local idHerbGarden = nil;
local visibleHerbGarden = false;

-- LunarfallExcavation
local TITAN_LUNARFALL_EXCAVATION_ID = "LunarfallExcavation";
local TITAN_LUNARFALL_EXCAVATION_ICON = "Interface\\ICONS\\Trade_Mining";
local idLunarfallExcavation = nil;
local visibleLunarfallExcavation = false;

-- FrostwallMines
local TITAN_FROSTWALL_MINES_ID = "FrostwallMines";
local TITAN_FROSTWALL_MINES_ICON = "Interface\\ICONS\\Trade_Mining";
local idFrostwallMines = nil;
local visibleFrostwallMines = false;

-- === VARIABLES ===

-- Libraries
local LT = LibStub("AceLocale-3.0"):GetLocale("Titan", true);
local L = LibStub("AceLocale-3.0"):GetLocale("Titan_WorkOrders", true);
local AceTimer = LibStub("AceTimer-3.0");

-- Thresholds
local greenTimeThreshold = 5;
local greenShipmentThreshold = 1;
local redShipmentThreshold = 1;

-- Timer
local timer = nil;
local scheduleScan = false;
local timerInterval = 1;



-- ========================
-- === GLOBAL FUNCTIONS ===
-- ========================

-- === FUNCTIONS WITH BUILDING-SPECIFIC VARIABLES ===

-- Scan Buildings
local function ScanBuildings()

-- //// ADD HERE \\\\

	idEngineeringWorks = nil;
	idTheTannery = nil;
	idAlchemyLab = nil;
	idEnchantersStudy = nil;
	idGemBoutique = nil;
	idScribesQuarters = nil;
	idTailoringEmporium = nil;
	idTheForge = nil;
	idBarn = nil;
	idLumberMill = nil;
	idTradingPost = nil;
	idDwarvenBunker = nil;
	idWarMill = nil;
	idHerbGarden = nil;
	idLunarfallExcavation = nil;
	idFrostwallMines = nil;

-- \\\\ ADD HERE ////   

	local buildings = C_Garrison.GetBuildings();	
	if debugScanBuildings then print('Titan [Work Orders][ScanBuildings]: Scanning a total of ' .. #buildings .. ' buildings.') end	
	
    for i = 1, #buildings do
		local buildingID = buildings[i].buildingID;
		local name, texture, shipmentCapacity, shipmentsReady, shipmentsTotal, creationTime, duration, timeLeftString, itemName, itemIcon, itemQuality, itemID = C_Garrison.GetLandingPageShipmentInfo(buildingID);

-- //// ADD HERE \\\\

		if name == L["TITAN_ENGINEERING_WORKS_BUILDING_NAME"] then
			idEngineeringWorks = buildingID;
			if debugScanBuildings then print('Titan [Work Orders][ScanBuildings]: Building found: ' .. name .. ' at ID: ' .. buildingID) end
        end
		if name == L["TITAN_THE_TANNERY_BUILDING_NAME"] then
			idTheTannery = buildingID;
			if debugScanBuildings then print('Titan [Work Orders][ScanBuildings]: Building found: ' .. name .. ' at ID: ' .. buildingID) end
        end
		if name == L["TITAN_ALCHEMY_LAB_BUILDING_NAME"] then
			idAlchemyLab = buildingID;
			if debugScanBuildings then print('Titan [Work Orders][ScanBuildings]: Building found: ' .. name .. ' at ID: ' .. buildingID) end
        end
		if name == L["TITAN_ENCHANTERS_STUDY_BUILDING_NAME"] then
			idEnchantersStudy = buildingID;
			if debugScanBuildings then print('Titan [Work Orders][ScanBuildings]: Building found: ' .. name .. ' at ID: ' .. buildingID) end
        end
		if name == L["TITAN_GEM_BOUTIQUE_BUILDING_NAME"] then
			idGemBoutique = buildingID;
			if debugScanBuildings then print('Titan [Work Orders][ScanBuildings]: Building found: ' .. name .. ' at ID: ' .. buildingID) end
        end
		if name == L["TITAN_SCRIBES_QUARTERS_BUILDING_NAME"] then
			idScribesQuarters = buildingID;
			if debugScanBuildings then print('Titan [Work Orders][ScanBuildings]: Building found: ' .. name .. ' at ID: ' .. buildingID) end
        end
		if name == L["TITAN_TAILORING_EMPORIUM_BUILDING_NAME"] then
			idTailoringEmporium = buildingID;
			if debugScanBuildings then print('Titan [Work Orders][ScanBuildings]: Building found: ' .. name .. ' at ID: ' .. buildingID) end
        end
		if name == L["TITAN_THE_FORGE_BUILDING_NAME"] then
			idTheForge = buildingID;
			if debugScanBuildings then print('Titan [Work Orders][ScanBuildings]: Building found: ' .. name .. ' at ID: ' .. buildingID) end
        end
		if name == L["TITAN_BARN_BUILDING_NAME"] then
			idBarn = buildingID;
			if debugScanBuildings then print('Titan [Work Orders][ScanBuildings]: Building found: ' .. name .. ' at ID: ' .. buildingID) end
        end
		if name == L["TITAN_LUMBER_MILL_BUILDING_NAME"] then
			idLumberMill = buildingID;
			if debugScanBuildings then print('Titan [Work Orders][ScanBuildings]: Building found: ' .. name .. ' at ID: ' .. buildingID) end
        end
		if name == L["TITAN_TRADING_POST_BUILDING_NAME"] then
			idTradingPost = buildingID;
			if debugScanBuildings then print('Titan [Work Orders][ScanBuildings]: Building found: ' .. name .. ' at ID: ' .. buildingID) end
        end
		if name == L["TITAN_DWARVEN_BUNKER_BUILDING_NAME"] then
			idDwarvenBunker = buildingID;
			if debugScanBuildings then print('Titan [Work Orders][ScanBuildings]: Building found: ' .. name .. ' at ID: ' .. buildingID) end
        end
		if name == L["TITAN_WAR_MILL_BUILDING_NAME"] then
			idWarMill = buildingID;
			if debugScanBuildings then print('Titan [Work Orders][ScanBuildings]: Building found: ' .. name .. ' at ID: ' .. buildingID) end
        end
		if name == L["TITAN_HERB_GARDEN_BUILDING_NAME"] then
			idHerbGarden = buildingID;
			if debugScanBuildings then print('Titan [Work Orders][ScanBuildings]: Building found: ' .. name .. ' at ID: ' .. buildingID) end
        end
		if name == L["TITAN_LUNARFALL_EXCAVATION_BUILDING_NAME"] then
			idLunarfallExcavation = buildingID;
			if debugScanBuildings then print('Titan [Work Orders][ScanBuildings]: Building found: ' .. name .. ' at ID: ' .. buildingID) end
        end
		if name == L["TITAN_FROSTWALL_MINES_BUILDING_NAME"] then
			idFrostwallMines = buildingID;
			if debugScanBuildings then print('Titan [Work Orders][ScanBuildings]: Building found: ' .. name .. ' at ID: ' .. buildingID) end
        end
        
-- \\\\ ADD HERE ////     

     end  
end   

-- Handle Hide
local function HandleHide(titanID)
	if debugHandleHide then print('Titan [Work Orders][HandleHide][' .. titanID .. ']: HandleHide activated.') end

-- //// ADD HERE \\\\

	if 
	not visibleEngineeringWorks and 
	not visibleTheTannery and 
	not visibleAlchemyLab and 
	not visibleEnchantersStudy and 
	not visibleGemBoutique and 
	not visibleScribesQuarters and 
	not visibleTailoringEmporium and 
	not visibleTheForge and 
	not visibleBarn and 
	not visibleLumberMill and 
	not visibleTradingPost and 
	not visibleDwarvenBunker and 
	not visibleWarMill and 
	not visibleHerbGarden and 
	not visibleLunarfallExcavation and 
	not visibleFrostwallMines 
	then
	
-- \\\\ ADD HERE ////     
	
		AceTimer.CancelTimer(TITAN_WORK_ORDERS_TIMER, timer, true)
		timer = nil;
		if debugHandleHide then print('Titan [Work Orders][HandleHide][' .. titanID .. ']: Timer destroyed. ') end
	end	
end	

-- Use Visibility
local function UseVisibility()

-- //// ADD HERE \\\\
		
	if visibleEngineeringWorks then
		TitanPanelButton_UpdateButton(TITAN_ENGINEERING_WORKS_ID);
	end	
	if visibleTheTannery then
		TitanPanelButton_UpdateButton(TITAN_THE_TANNERY_ID);
	end	
	if visibleAlchemyLab then
		TitanPanelButton_UpdateButton(TITAN_ALCHEMY_LAB_ID);
	end	
	if visibleEnchantersStudy then
		TitanPanelButton_UpdateButton(TITAN_ENCHANTERS_STUDY_ID);
	end	
	if visibleGemBoutique then
		TitanPanelButton_UpdateButton(TITAN_GEM_BOUTIQUE_ID);
	end	
	if visibleScribesQuarters then
		TitanPanelButton_UpdateButton(TITAN_SCRIBES_QUARTERS_ID);
	end	
	if visibleTailoringEmporium then
		TitanPanelButton_UpdateButton(TITAN_TAILORING_EMPORIUM_ID);
	end	
	if visibleTheForge then
		TitanPanelButton_UpdateButton(TITAN_THE_FORGE_ID);
	end	
	if visibleBarn then
		TitanPanelButton_UpdateButton(TITAN_BARN_ID);
	end	
	if visibleLumberMill then
		TitanPanelButton_UpdateButton(TITAN_LUMBER_MILL_ID);
	end	
	if visibleTradingPost then
		TitanPanelButton_UpdateButton(TITAN_TRADING_POST_ID);
	end	
	if visibleDwarvenBunker then
		TitanPanelButton_UpdateButton(TITAN_DWARVEN_BUNKER_ID);
	end	
	if visibleWarMill then
		TitanPanelButton_UpdateButton(TITAN_WAR_MILL_ID);
	end	
	if visibleHerbGarden then
		TitanPanelButton_UpdateButton(TITAN_HERB_GARDEN_ID);
	end	
	if visibleLunarfallExcavation then
		TitanPanelButton_UpdateButton(TITAN_LUNARFALL_EXCAVATION_ID);
	end	
	if visibleFrostwallMines then
		TitanPanelButton_UpdateButton(TITAN_FROSTWALL_MINES_ID);
	end	
	
-- \\\\ ADD HERE ////  

end



-- === SCANNING FUNCTIONS ===

-- Event Handler
local function EventHandler(event)
	if not scheduleScan then
		if event == "GARRISON_BUILDING_UPDATE" then
			if debugEvents then print('GARRISON_BUILDING_UPDATE') end 
			scheduleScan = true;
			if debugEventHandler then print('Titan [Work Orders][EventHandler]: Requested building scan.') end 
		end
		if event == "GARRISON_BUILDING_ACTIVATABLE" then
			if debugEvents then print('GARRISON_BUILDING_ACTIVATABLE') end 
			scheduleScan = true;
			if debugEventHandler then print('Titan [Work Orders][EventHandler]: Requested building scan.') end 
		end
		if event == "GARRISON_BUILDING_ACTIVATED" then
			if debugEvents then print('GARRISON_BUILDING_ACTIVATED') end 
			scheduleScan = true;
			if debugEventHandler then print('Titan [Work Orders][EventHandler]: Requested building scan.') end 
		end
		if event == "GARRISON_BUILDING_LIST_UPDATE" then
			if debugEvents then print('GARRISON_BUILDING_LIST_UPDATE') end 
			scheduleScan = true;
			if debugEventHandler then print('Titan [Work Orders][EventHandler]: Requested building scan.') end 
		end
	end	
end 

-- === STRING MANIPULATION ===    
    
-- Convert Time String
local function ConvertTimeString(str, c)
    local t = '';
    local l = GetLocale();

    if localeMapping[l] == nil then
        return 0;
    end

	-- Split h m s
    local h = string.match(str, localeMapping[l].hr);
    if h then
        h = tonumber(string.match(h, '(%d+)'));
    end

    local m = string.match(str, localeMapping[l].min);
    if m then
        m = tonumber(string.match(m, '(%d+)'));
    end

    local s = string.match(str, localeMapping[l].sec);
    if s then
        s = tonumber(string.match(s, '(%d+)'));
    end

	-- Format string
	if h then
		if m then
			if m < 10 then
				t = h .. ':0' .. m;
			else
				t = h .. ':' .. m;
			end	
		else
			t = h .. ':00';
		end	
	else
		if m then
			if m < 10 then
				t = '0:0' .. m;
			else
				t = '0:' .. m;
			end
		else
			if s then
				if s < 10 then
					t = '0' .. s .. L["TITAN_WORK_ORDERS_TIME_S"];
				else
					t = s .. L["TITAN_WORK_ORDERS_TIME_S"];
				end
			end
		end
	end

	-- Format color	
	if c then
		if h then
			t = GRAY_FONT_COLOR_CODE .. t .. FONT_COLOR_CODE_CLOSE;
		else	
			if m then
				if m > greenTimeThreshold then
					t = HIGHLIGHT_FONT_COLOR_CODE .. t .. FONT_COLOR_CODE_CLOSE;
				else
					t = GREEN_FONT_COLOR_CODE .. t .. FONT_COLOR_CODE_CLOSE;
				end	
			else
				t = GREEN_FONT_COLOR_CODE .. t .. FONT_COLOR_CODE_CLOSE;
			end
		end
	else
		t = HIGHLIGHT_FONT_COLOR_CODE .. t .. FONT_COLOR_CODE_CLOSE;
	end
			
	return t;
end

-- Format Shipment String
local function FormatShipmentString(shipmentsReady, shipmentsTotal, shipmentCapacity, c)
	local str = '';
	
	if c then
		if (shipmentsTotal - shipmentsReady) <= redShipmentThreshold then
			str = RED_FONT_COLOR_CODE .. shipmentsReady .. '/' .. shipmentsTotal .. FONT_COLOR_CODE_CLOSE .. GRAY_FONT_COLOR_CODE .. ' [' .. shipmentCapacity .. ']' .. FONT_COLOR_CODE_CLOSE;
		elseif shipmentsReady >= greenShipmentThreshold then
			str = GREEN_FONT_COLOR_CODE .. shipmentsReady .. '/' .. shipmentsTotal .. FONT_COLOR_CODE_CLOSE .. GRAY_FONT_COLOR_CODE .. ' [' .. shipmentCapacity .. ']' .. FONT_COLOR_CODE_CLOSE;
		else
			str = GRAY_FONT_COLOR_CODE .. shipmentsReady .. '/' .. shipmentsTotal .. FONT_COLOR_CODE_CLOSE .. GRAY_FONT_COLOR_CODE .. ' [' .. shipmentCapacity .. ']' .. FONT_COLOR_CODE_CLOSE;
		end	
	else
		str = HIGHLIGHT_FONT_COLOR_CODE .. shipmentsReady .. '/' .. shipmentsTotal .. ' [' .. shipmentCapacity .. ']' .. FONT_COLOR_CODE_CLOSE;
	end			
	
	return str;	
end	

-- Format Full Text
local function FormatColorText(name, timeLeftString, shipmentsReady, shipmentsTotal, shipmentCapacity, c)
	local str = '';
	
	if shipmentsReady ~=  shipmentsTotal then       
		if timeLeftString then
			str = ConvertTimeString(timeLeftString, c) .. ' ' .. FormatShipmentString(shipmentsReady, shipmentsTotal, shipmentCapacity, c);
		else
			str = ConvertTimeString('0 sec', c) .. ' ' .. FormatShipmentString(shipmentsReady, shipmentsTotal, shipmentCapacity, c);
		end	
	else
		if shipmentCapacity then
			if shipmentsTotal then
				str = FormatShipmentString(shipmentsReady, shipmentsTotal, shipmentCapacity, c);
			else	
				str = FormatShipmentString(0, 0, shipmentCapacity, c);
			end	
		end	
	end
	return str;	
end	

-- Not Built
local function NotBuilt(id)
	TitanPanelPluginHandle_OnUpdate(updateTable);
	
	local str = '';	
				
	if TitanGetVar(id, "ShowColoredText") then
		str = L["TITAN_WORK_ORDERS_NOT_BUILT"];
	else
		str = L["TITAN_WORK_ORDERS_NOT_BUILT_PLAIN"];
	end		
	
	return str;	
end	

-- Fetch Text
local function FetchText(titanID, buildingID)	
	local str = '';	
	
	local name, texture, shipmentCapacity, shipmentsReady, shipmentsTotal, creationTime, duration, timeLeftString, itemName, itemIcon, itemQuality, itemID = C_Garrison.GetLandingPageShipmentInfo(buildingID);
	str = FormatColorText(name, timeLeftString, shipmentsReady, shipmentsTotal, shipmentCapacity, TitanGetVar(titanID, "ShowColoredText"));    
	
	return str;	
end	

-- Handle Update
local function HandleUpdate(titanID, buildingID)
	if buildingID then
		return FetchText(titanID, buildingID);
	else
		return NotBuilt(titanID);
	end	
end	

-- Build Tooltip
local function BuildTooltip(buildingID)
	
	local str = '';	
	local shipmentsLeft = nil;
    local l = GetLocale();	
		
    if localeMapping[l] == nil then
        return 0;
    end

	-- Status	
	str = str .. L["TITAN_WORK_ORDERS_TOOLTIP_STATUS"] .. '\t';
		
	local name, texture, shipmentCapacity, shipmentsReady, shipmentsTotal, creationTime, duration, timeLeftString, itemName, itemIcon, itemQuality, itemID = C_Garrison.GetLandingPageShipmentInfo(buildingID);
	if shipmentsReady and shipmentsTotal then
		shipmentsLeft = shipmentsTotal - shipmentsReady;
	end	

	if timeLeftString then
		str = str .. L["TITAN_WORK_ORDERS_TOOLTIP_STATUS_ACTIVE"];
	else
		str = str .. L["TITAN_WORK_ORDERS_TOOLTIP_STATUS_INACTIVE"];
	end	
	
	-- Product	
	str = str .. '\n' .. L["TITAN_WORK_ORDERS_TOOLTIP_PRODUCT"] .. '\t';
	if itemName then
		local r, g, b, hex = GetItemQualityColor(itemQuality);
		str = str .. '|c' .. hex .. '[' .. itemName .. ']|r';
	else
		str = str .. GRAY_FONT_COLOR_CODE .. 'None' .. FONT_COLOR_CODE_CLOSE;
	end	
			
	-- Time left	
	-- Split h m s
	if timeLeftString then
		local h = string.match(timeLeftString, localeMapping[l].hr);
		if h then
			h = tonumber(string.match(h, '(%d+)'));
		end

		local m = string.match(timeLeftString, localeMapping[l].min);
		if m then
			m = tonumber(string.match(m, '(%d+)'));
		end

		local s = string.match(timeLeftString, localeMapping[l].sec);
		if s then
			s = tonumber(string.match(s, '(%d+)'));
		end
    
		-- Format color	
		if h then
			str = str .. '\n' .. L["TITAN_WORK_ORDERS_TOOLTIP_NEXT"] .. '\t';
			str = str .. HIGHLIGHT_FONT_COLOR_CODE .. timeLeftString .. FONT_COLOR_CODE_CLOSE;
		else	
			if m then
				str = str .. '\n' .. L["TITAN_WORK_ORDERS_TOOLTIP_NEXT"] .. '\t';
				if m > greenTimeThreshold then
					str = str .. HIGHLIGHT_FONT_COLOR_CODE .. timeLeftString .. FONT_COLOR_CODE_CLOSE;
				else
					str = str .. GREEN_FONT_COLOR_CODE .. timeLeftString .. FONT_COLOR_CODE_CLOSE;
				end	
			else
				if s then
					str = str .. '\n' .. L["TITAN_WORK_ORDERS_TOOLTIP_NEXT"] .. '\t';
					str = str .. GREEN_FONT_COLOR_CODE .. '<1 ' .. L["TITAN_WORK_ORDERS_TIME_M"] .. FONT_COLOR_CODE_CLOSE;
				end
			end
		end
	end	
	
	-- Ready count	
	str = str .. '\n' .. L["TITAN_WORK_ORDERS_TOOLTIP_READY"] .. '\t';
	if shipmentsReady then
		if shipmentsReady >= greenShipmentThreshold then
			str = str .. GREEN_FONT_COLOR_CODE .. shipmentsReady .. FONT_COLOR_CODE_CLOSE;
		else
			str = str .. GRAY_FONT_COLOR_CODE .. shipmentsReady .. FONT_COLOR_CODE_CLOSE;
		end
	else
		str = str .. GRAY_FONT_COLOR_CODE .. '0' .. FONT_COLOR_CODE_CLOSE;
	end	
	
	-- Left count	
	str = str .. '\n' .. L["TITAN_WORK_ORDERS_TOOLTIP_LEFT"] .. '\t';	
	if shipmentsLeft then
		if shipmentsLeft <= redShipmentThreshold then
			str = str .. RED_FONT_COLOR_CODE .. shipmentsLeft .. FONT_COLOR_CODE_CLOSE;
		else
			str = str .. HIGHLIGHT_FONT_COLOR_CODE .. shipmentsLeft .. FONT_COLOR_CODE_CLOSE;
		end
	else
		str = str .. RED_FONT_COLOR_CODE .. '0' .. FONT_COLOR_CODE_CLOSE;
	end	
	
	-- Total count	
	str = str .. '\n' .. L["TITAN_WORK_ORDERS_TOOLTIP_TOTAL"] .. '\t';	
	if shipmentsTotal then
		if shipmentsTotal == 0 then
			str = str .. RED_FONT_COLOR_CODE .. shipmentsTotal .. FONT_COLOR_CODE_CLOSE;
		else
			str = str .. HIGHLIGHT_FONT_COLOR_CODE .. shipmentsTotal .. FONT_COLOR_CODE_CLOSE;
		end
	else
		str = str .. RED_FONT_COLOR_CODE .. '0' .. FONT_COLOR_CODE_CLOSE;
	end	
	
	-- Capacity count	
	str = str .. '\n' .. L["TITAN_WORK_ORDERS_TOOLTIP_CAPACITY"] .. '\t';	
	str = str .. HIGHLIGHT_FONT_COLOR_CODE .. shipmentCapacity .. FONT_COLOR_CODE_CLOSE;
	
	-- Tooltip hint	
	str = str .. '\n\n' .. L["TITAN_WORK_ORDERS_TOOLTIP_HINT"];
			
	return str;
	
end

-- Prepare Tooltip
function PrepareTooltip(buildingID)	
	if buildingID then
		return BuildTooltip(buildingID);
	else
		return L["TITAN_WORK_ORDERS_TOOLTIP_STATUS"] .. '\t' .. L["TITAN_WORK_ORDERS_NOT_BUILT"];
	end	
end



-- === BUTTON SPECIFIC ===

-- Build Menu
local function BuildMenu(titanID)	
	TitanPanelRightClickMenu_AddToggleIcon(titanID);
	TitanPanelRightClickMenu_AddToggleLabelText(titanID);
	TitanPanelRightClickMenu_AddToggleColoredText(titanID);
	
	TitanPanelRightClickMenu_AddSpacer();
	
	TitanPanelRightClickMenu_AddCommand(LT["TITAN_PANEL_MENU_HIDE"], titanID, TITAN_PANEL_MENU_FUNC_HIDE);
end	

-- Handle Click
local function HandleClick(button)
	if (button == "LeftButton") then
		GarrisonLandingPage_Toggle();
	end
end	



-- === TIMER ===

-- Handle Tick
local function HandleTick()

	C_Garrison.RequestLandingPageShipmentInfo();

	if scheduleScan then
		if debugHandleATick then print('Titan [Work Orders][HandleATick]: Building scan accepted.') end
		ScanBuildings();
		scheduleScan = false;
		if debugHandleATick then print('Titan [Work Orders][HandleATick]: Buildings scanned.') end
	end

	UseVisibility();

end	

-- Handle Timer
local function HandleTimer(titanID, visibility)
	if TitanGetVar(titanID, "ShowLabelText") then
		if not visibility then
			scheduleScan = true;
			if debugHandleTimer then print('Titan [Work Orders][HandleTimer][' .. titanID .. ']: Requested building scan. ') end
			if not timer then
				timer = AceTimer.ScheduleRepeatingTimer(TITAN_WORK_ORDERS_TIMER, HandleTick, timerInterval);
				if debugHandleTimer then print('Titan [Work Orders][HandleTimer][' .. titanID .. ']: Timer started. ') end
			end
		end	
		return true;
	else	
		return false;
	end
end	



-- =================
-- === BUILDINGS ===
-- =================



-- === ENGINEERING_WORKS ===

-- OnLoad
function TitanPanelEngineeringWorksButton_OnLoad(self)
	self.registry = {
		id = TITAN_ENGINEERING_WORKS_ID,
		category = TITAN_WORK_ORDERS_CATEGORY,
		version = TITAN_WORK_ORDERS_VERSION,
		menuText = L["TITAN_ENGINEERING_WORKS_MENU_TEXT"],
		buttonTextFunction = "TitanPanelEngineeringWorksButton_GetButtonText", 
		tooltipTitle = L["TITAN_ENGINEERING_WORKS_TOOLTIP_TITLE"],
		tooltipTextFunction = "TitanPanelEngineeringWorksButton_GetTooltipText",
		icon = TITAN_ENGINEERING_WORKS_ICON,
		
		iconWidth = 16,
		savedVariables = {        
			ShowIcon = true,
			ShowLabelText = true,
			ShowColoredText = true,
			DisplayOnRightSide = false,
		}
	};     
	self:RegisterEvent("PLAYER_ENTERING_WORLD");
end

-- OnEvent
function TitanPanelEngineeringWorksButton_OnEvent(self, event, ...)
	if (event == "PLAYER_ENTERING_WORLD") 
	and ((not self:IsEventRegistered("GARRISON_BUILDING_UPDATE")) 
	or (not self:IsEventRegistered("GARRISON_BUILDING_ACTIVATABLE")) 
	or (not self:IsEventRegistered("GARRISON_BUILDING_ACTIVATED"))
	or (not self:IsEventRegistered("GARRISON_BUILDING_LIST_UPDATE"))) then
		if debugEvents then print('PLAYER_ENTERING_WORLD') end 
		self:RegisterEvent("GARRISON_BUILDING_UPDATE");
		self:RegisterEvent("GARRISON_BUILDING_ACTIVATABLE");
		self:RegisterEvent("GARRISON_BUILDING_ACTIVATED");
		self:RegisterEvent("GARRISON_BUILDING_LIST_UPDATE");
	end	   
	EventHandler(event);
end

-- OnShow
function TitanPanelEngineeringWorksButton_OnShow()
	if debugOnShow then print('Titan [Work Orders][OnShow][' .. TITAN_ENGINEERING_WORKS_ID .. ']: OnShow fired.') end
	visibleEngineeringWorks = HandleTimer(TITAN_ENGINEERING_WORKS_ID, visibleEngineeringWorks);
end

-- OnHide
function TitanPanelEngineeringWorksButton_OnHide()
	visibleEngineeringWorks = false;
	HandleHide(TITAN_ENGINEERING_WORKS_ID);
end

-- GetButtonText
function TitanPanelEngineeringWorksButton_GetButtonText(id)
	
	if TitanGetVar(TITAN_ENGINEERING_WORKS_ID, "ShowLabelText") then
		visibleEngineeringWorks = HandleTimer(TITAN_ENGINEERING_WORKS_ID, visibleEngineeringWorks);
		return '', HandleUpdate(TITAN_ENGINEERING_WORKS_ID, idEngineeringWorks);	
	else
		visibleEngineeringWorks = false;
		HandleHide(TITAN_ENGINEERING_WORKS_ID);
		if TitanGetVar(TITAN_ENGINEERING_WORKS_ID, "ShowIcon") then
			return '', '';
		else
			return HIGHLIGHT_FONT_COLOR_CODE .. L["TITAN_ENGINEERING_WORKS_TOOLTIP_TITLE"] .. FONT_COLOR_CODE_CLOSE;
		end		
	end
	
end

-- SetTooltip
function TitanPanelEngineeringWorksButton_GetTooltipText()
	C_Garrison.RequestLandingPageShipmentInfo();
	ScanBuildings();
	return PrepareTooltip(idEngineeringWorks)
end

-- OnClick
function TitanPanelEngineeringWorksButton_OnClick(self, button)
	HandleClick(button);
end

-- PrepareMenu
function TitanPanelRightClickMenu_PrepareEngineeringWorksMenu()

	TitanPanelRightClickMenu_AddTitle(TitanPlugins[TITAN_ENGINEERING_WORKS_ID].menuText);
	
	TitanPanelRightClickMenu_AddSpacer();

	info = {};
	info.text = L["TITAN_WORK_ORDERS_RIGHT_SIDE"];
	info.func = TitanPanelEngineeringWorksButton_ToggleRightSideDisplay;
	info.checked = TitanGetVar(TITAN_ENGINEERING_WORKS_ID, "DisplayOnRightSide");
	UIDropDownMenu_AddButton(info);
	
	BuildMenu(TITAN_ENGINEERING_WORKS_ID);
	
end

-- ToggleRightSideDisplay
function TitanPanelEngineeringWorksButton_ToggleRightSideDisplay()
	TitanToggleVar(TITAN_ENGINEERING_WORKS_ID, "DisplayOnRightSide");
	TitanPanel_InitPanelButtons();
end



-- === THE_TANNERY ===

-- OnLoad
function TitanPanelTheTanneryButton_OnLoad(self)
	self.registry = {
		id = TITAN_THE_TANNERY_ID,
		category = TITAN_WORK_ORDERS_CATEGORY,
		version = TITAN_WORK_ORDERS_VERSION,
		menuText = L["TITAN_THE_TANNERY_MENU_TEXT"],
		buttonTextFunction = "TitanPanelTheTanneryButton_GetButtonText", 
		tooltipTitle = L["TITAN_THE_TANNERY_TOOLTIP_TITLE"],
		tooltipTextFunction = "TitanPanelTheTanneryButton_GetTooltipText",
		icon = TITAN_THE_TANNERY_ICON,
		
		iconWidth = 16,
		savedVariables = {        
			ShowIcon = true,
			ShowLabelText = true,
			ShowColoredText = true,
			DisplayOnRightSide = false,
		}
	};     
	self:RegisterEvent("PLAYER_ENTERING_WORLD");
end

-- OnEvent
function TitanPanelTheTanneryButton_OnEvent(self, event, ...)
	if (event == "PLAYER_ENTERING_WORLD") 
	and ((not self:IsEventRegistered("GARRISON_BUILDING_UPDATE")) 
	or (not self:IsEventRegistered("GARRISON_BUILDING_ACTIVATABLE")) 
	or (not self:IsEventRegistered("GARRISON_BUILDING_ACTIVATED"))
	or (not self:IsEventRegistered("GARRISON_BUILDING_LIST_UPDATE"))) then
		if debugEvents then print('PLAYER_ENTERING_WORLD') end 
		self:RegisterEvent("GARRISON_BUILDING_UPDATE");
		self:RegisterEvent("GARRISON_BUILDING_ACTIVATABLE");
		self:RegisterEvent("GARRISON_BUILDING_ACTIVATED");
		self:RegisterEvent("GARRISON_BUILDING_LIST_UPDATE");
	end	   
	EventHandler(event);
end

-- OnShow
function TitanPanelTheTanneryButton_OnShow()
	if debugOnShow then print('Titan [Work Orders][OnShow][' .. TITAN_THE_TANNERY_ID .. ']: OnShow fired.') end
	visibleTheTannery = HandleTimer(TITAN_THE_TANNERY_ID, visibleTheTannery);
end

-- OnHide
function TitanPanelTheTanneryButton_OnHide()
	visibleTheTannery = false;
	HandleHide(TITAN_THE_TANNERY_ID);
end

-- GetButtonText
function TitanPanelTheTanneryButton_GetButtonText(id)
	
	if TitanGetVar(TITAN_THE_TANNERY_ID, "ShowLabelText") then
		visibleTheTannery = HandleTimer(TITAN_THE_TANNERY_ID, visibleTheTannery);
		return '', HandleUpdate(TITAN_THE_TANNERY_ID, idTheTannery);	
	else
		visibleTheTannery = false;
		HandleHide(TITAN_THE_TANNERY_ID);
		if TitanGetVar(TITAN_THE_TANNERY_ID, "ShowIcon") then
			return '', '';
		else
			return HIGHLIGHT_FONT_COLOR_CODE .. L["TITAN_THE_TANNERY_TOOLTIP_TITLE"] .. FONT_COLOR_CODE_CLOSE;
		end		
	end
	
end

-- SetTooltip
function TitanPanelTheTanneryButton_GetTooltipText()
	C_Garrison.RequestLandingPageShipmentInfo();
	ScanBuildings();
	return PrepareTooltip(idTheTannery)
end

-- OnClick
function TitanPanelTheTanneryButton_OnClick(self, button)
	HandleClick(button);
end

-- PrepareMenu
function TitanPanelRightClickMenu_PrepareTheTanneryMenu()

	TitanPanelRightClickMenu_AddTitle(TitanPlugins[TITAN_THE_TANNERY_ID].menuText);
	
	TitanPanelRightClickMenu_AddSpacer();

	info = {};
	info.text = L["TITAN_WORK_ORDERS_RIGHT_SIDE"];
	info.func = TitanPanelTheTanneryButton_ToggleRightSideDisplay;
	info.checked = TitanGetVar(TITAN_THE_TANNERY_ID, "DisplayOnRightSide");
	UIDropDownMenu_AddButton(info);
	
	BuildMenu(TITAN_THE_TANNERY_ID);
	
end

-- ToggleRightSideDisplay
function TitanPanelTheTanneryButton_ToggleRightSideDisplay()
	TitanToggleVar(TITAN_THE_TANNERY_ID, "DisplayOnRightSide");
	TitanPanel_InitPanelButtons();
end



-- === ALCHEMY_LAB ===

-- OnLoad
function TitanPanelAlchemyLabButton_OnLoad(self)
	self.registry = {
		id = TITAN_ALCHEMY_LAB_ID,
		category = TITAN_WORK_ORDERS_CATEGORY,
		version = TITAN_WORK_ORDERS_VERSION,
		menuText = L["TITAN_ALCHEMY_LAB_MENU_TEXT"],
		buttonTextFunction = "TitanPanelAlchemyLabButton_GetButtonText", 
		tooltipTitle = L["TITAN_ALCHEMY_LAB_TOOLTIP_TITLE"],
		tooltipTextFunction = "TitanPanelAlchemyLabButton_GetTooltipText",
		icon = TITAN_ALCHEMY_LAB_ICON,
		
		iconWidth = 16,
		savedVariables = {        
			ShowIcon = true,
			ShowLabelText = true,
			ShowColoredText = true,
			DisplayOnRightSide = false,
		}
	};     
	self:RegisterEvent("PLAYER_ENTERING_WORLD");
end

-- OnEvent
function TitanPanelAlchemyLabButton_OnEvent(self, event, ...)
	if (event == "PLAYER_ENTERING_WORLD") 
	and ((not self:IsEventRegistered("GARRISON_BUILDING_UPDATE")) 
	or (not self:IsEventRegistered("GARRISON_BUILDING_ACTIVATABLE")) 
	or (not self:IsEventRegistered("GARRISON_BUILDING_ACTIVATED"))
	or (not self:IsEventRegistered("GARRISON_BUILDING_LIST_UPDATE"))) then
		if debugEvents then print('PLAYER_ENTERING_WORLD') end 
		self:RegisterEvent("GARRISON_BUILDING_UPDATE");
		self:RegisterEvent("GARRISON_BUILDING_ACTIVATABLE");
		self:RegisterEvent("GARRISON_BUILDING_ACTIVATED");
		self:RegisterEvent("GARRISON_BUILDING_LIST_UPDATE");
	end	   
	EventHandler(event);
end

-- OnShow
function TitanPanelAlchemyLabButton_OnShow()
	if debugOnShow then print('Titan [Work Orders][OnShow][' .. TITAN_ALCHEMY_LAB_ID .. ']: OnShow fired.') end
	visibleAlchemyLab = HandleTimer(TITAN_ALCHEMY_LAB_ID, visibleAlchemyLab);
end

-- OnHide
function TitanPanelAlchemyLabButton_OnHide()
	visibleAlchemyLab = false;
	HandleHide(TITAN_ALCHEMY_LAB_ID);
end

-- GetButtonText
function TitanPanelAlchemyLabButton_GetButtonText(id)
	
	if TitanGetVar(TITAN_ALCHEMY_LAB_ID, "ShowLabelText") then
		visibleAlchemyLab = HandleTimer(TITAN_ALCHEMY_LAB_ID, visibleAlchemyLab);
		return '', HandleUpdate(TITAN_ALCHEMY_LAB_ID, idAlchemyLab);	
	else
		visibleAlchemyLab = false;
		HandleHide(TITAN_ALCHEMY_LAB_ID);
		if TitanGetVar(TITAN_ALCHEMY_LAB_ID, "ShowIcon") then
			return '', '';
		else
			return HIGHLIGHT_FONT_COLOR_CODE .. L["TITAN_ALCHEMY_LAB_TOOLTIP_TITLE"] .. FONT_COLOR_CODE_CLOSE;
		end		
	end
	
end

-- SetTooltip
function TitanPanelAlchemyLabButton_GetTooltipText()
	C_Garrison.RequestLandingPageShipmentInfo();
	ScanBuildings();
	return PrepareTooltip(idAlchemyLab)
end

-- OnClick
function TitanPanelAlchemyLabButton_OnClick(self, button)
	HandleClick(button);
end

-- PrepareMenu
function TitanPanelRightClickMenu_PrepareAlchemyLabMenu()

	TitanPanelRightClickMenu_AddTitle(TitanPlugins[TITAN_ALCHEMY_LAB_ID].menuText);
	
	TitanPanelRightClickMenu_AddSpacer();

	info = {};
	info.text = L["TITAN_WORK_ORDERS_RIGHT_SIDE"];
	info.func = TitanPanelAlchemyLabButton_ToggleRightSideDisplay;
	info.checked = TitanGetVar(TITAN_ALCHEMY_LAB_ID, "DisplayOnRightSide");
	UIDropDownMenu_AddButton(info);
	
	BuildMenu(TITAN_ALCHEMY_LAB_ID);
	
end

-- ToggleRightSideDisplay
function TitanPanelAlchemyLabButton_ToggleRightSideDisplay()
	TitanToggleVar(TITAN_ALCHEMY_LAB_ID, "DisplayOnRightSide");
	TitanPanel_InitPanelButtons();
end



-- === ENCHANTERS_STUDY ===

-- OnLoad
function TitanPanelEnchantersStudyButton_OnLoad(self)
	self.registry = {
		id = TITAN_ENCHANTERS_STUDY_ID,
		category = TITAN_WORK_ORDERS_CATEGORY,
		version = TITAN_WORK_ORDERS_VERSION,
		menuText = L["TITAN_ENCHANTERS_STUDY_MENU_TEXT"],
		buttonTextFunction = "TitanPanelEnchantersStudyButton_GetButtonText", 
		tooltipTitle = L["TITAN_ENCHANTERS_STUDY_TOOLTIP_TITLE"],
		tooltipTextFunction = "TitanPanelEnchantersStudyButton_GetTooltipText",
		icon = TITAN_ENCHANTERS_STUDY_ICON,
		
		iconWidth = 16,
		savedVariables = {        
			ShowIcon = true,
			ShowLabelText = true,
			ShowColoredText = true,
			DisplayOnRightSide = false,
		}
	};     
	self:RegisterEvent("PLAYER_ENTERING_WORLD");
end

-- OnEvent
function TitanPanelEnchantersStudyButton_OnEvent(self, event, ...)
	if (event == "PLAYER_ENTERING_WORLD") 
	and ((not self:IsEventRegistered("GARRISON_BUILDING_UPDATE")) 
	or (not self:IsEventRegistered("GARRISON_BUILDING_ACTIVATABLE")) 
	or (not self:IsEventRegistered("GARRISON_BUILDING_ACTIVATED"))
	or (not self:IsEventRegistered("GARRISON_BUILDING_LIST_UPDATE"))) then
		if debugEvents then print('PLAYER_ENTERING_WORLD') end 
		self:RegisterEvent("GARRISON_BUILDING_UPDATE");
		self:RegisterEvent("GARRISON_BUILDING_ACTIVATABLE");
		self:RegisterEvent("GARRISON_BUILDING_ACTIVATED");
		self:RegisterEvent("GARRISON_BUILDING_LIST_UPDATE");
	end	   
	EventHandler(event);
end

-- OnShow
function TitanPanelEnchantersStudyButton_OnShow()
	if debugOnShow then print('Titan [Work Orders][OnShow][' .. TITAN_ENCHANTERS_STUDY_ID .. ']: OnShow fired.') end
	visibleEnchantersStudy = HandleTimer(TITAN_ENCHANTERS_STUDY_ID, visibleEnchantersStudy);
end

-- OnHide
function TitanPanelEnchantersStudyButton_OnHide()
	visibleEnchantersStudy = false;
	HandleHide(TITAN_ENCHANTERS_STUDY_ID);
end

-- GetButtonText
function TitanPanelEnchantersStudyButton_GetButtonText(id)
	
	if TitanGetVar(TITAN_ENCHANTERS_STUDY_ID, "ShowLabelText") then
		visibleEnchantersStudy = HandleTimer(TITAN_ENCHANTERS_STUDY_ID, visibleEnchantersStudy);
		return '', HandleUpdate(TITAN_ENCHANTERS_STUDY_ID, idEnchantersStudy);	
	else
		visibleEnchantersStudy = false;
		HandleHide(TITAN_ENCHANTERS_STUDY_ID);
		if TitanGetVar(TITAN_ENCHANTERS_STUDY_ID, "ShowIcon") then
			return '', '';
		else
			return HIGHLIGHT_FONT_COLOR_CODE .. L["TITAN_ENCHANTERS_STUDY_TOOLTIP_TITLE"] .. FONT_COLOR_CODE_CLOSE;
		end		
	end
	
end

-- SetTooltip
function TitanPanelEnchantersStudyButton_GetTooltipText()
	C_Garrison.RequestLandingPageShipmentInfo();
	ScanBuildings();
	return PrepareTooltip(idEnchantersStudy)
end

-- OnClick
function TitanPanelEnchantersStudyButton_OnClick(self, button)
	HandleClick(button);
end

-- PrepareMenu
function TitanPanelRightClickMenu_PrepareEnchantersStudyMenu()

	TitanPanelRightClickMenu_AddTitle(TitanPlugins[TITAN_ENCHANTERS_STUDY_ID].menuText);
	
	TitanPanelRightClickMenu_AddSpacer();

	info = {};
	info.text = L["TITAN_WORK_ORDERS_RIGHT_SIDE"];
	info.func = TitanPanelEnchantersStudyButton_ToggleRightSideDisplay;
	info.checked = TitanGetVar(TITAN_ENCHANTERS_STUDY_ID, "DisplayOnRightSide");
	UIDropDownMenu_AddButton(info);
	
	BuildMenu(TITAN_ENCHANTERS_STUDY_ID);
	
end

-- ToggleRightSideDisplay
function TitanPanelEnchantersStudyButton_ToggleRightSideDisplay()
	TitanToggleVar(TITAN_ENCHANTERS_STUDY_ID, "DisplayOnRightSide");
	TitanPanel_InitPanelButtons();
end



-- === GEM_BOUTIQUE ===

-- OnLoad
function TitanPanelGemBoutiqueButton_OnLoad(self)
	self.registry = {
		id = TITAN_GEM_BOUTIQUE_ID,
		category = TITAN_WORK_ORDERS_CATEGORY,
		version = TITAN_WORK_ORDERS_VERSION,
		menuText = L["TITAN_GEM_BOUTIQUE_MENU_TEXT"],
		buttonTextFunction = "TitanPanelGemBoutiqueButton_GetButtonText", 
		tooltipTitle = L["TITAN_GEM_BOUTIQUE_TOOLTIP_TITLE"],
		tooltipTextFunction = "TitanPanelGemBoutiqueButton_GetTooltipText",
		icon = TITAN_GEM_BOUTIQUE_ICON,
		
		iconWidth = 16,
		savedVariables = {        
			ShowIcon = true,
			ShowLabelText = true,
			ShowColoredText = true,
			DisplayOnRightSide = false,
		}
	};     
	self:RegisterEvent("PLAYER_ENTERING_WORLD");
end

-- OnEvent
function TitanPanelGemBoutiqueButton_OnEvent(self, event, ...)
	if (event == "PLAYER_ENTERING_WORLD") 
	and ((not self:IsEventRegistered("GARRISON_BUILDING_UPDATE")) 
	or (not self:IsEventRegistered("GARRISON_BUILDING_ACTIVATABLE")) 
	or (not self:IsEventRegistered("GARRISON_BUILDING_ACTIVATED"))
	or (not self:IsEventRegistered("GARRISON_BUILDING_LIST_UPDATE"))) then
		if debugEvents then print('PLAYER_ENTERING_WORLD') end 
		self:RegisterEvent("GARRISON_BUILDING_UPDATE");
		self:RegisterEvent("GARRISON_BUILDING_ACTIVATABLE");
		self:RegisterEvent("GARRISON_BUILDING_ACTIVATED");
		self:RegisterEvent("GARRISON_BUILDING_LIST_UPDATE");
	end	   
	EventHandler(event);
end

-- OnShow
function TitanPanelGemBoutiqueButton_OnShow()
	if debugOnShow then print('Titan [Work Orders][OnShow][' .. TITAN_GEM_BOUTIQUE_ID .. ']: OnShow fired.') end
	visibleGemBoutique = HandleTimer(TITAN_GEM_BOUTIQUE_ID, visibleGemBoutique);
end

-- OnHide
function TitanPanelGemBoutiqueButton_OnHide()
	visibleGemBoutique = false;
	HandleHide(TITAN_GEM_BOUTIQUE_ID);
end

-- GetButtonText
function TitanPanelGemBoutiqueButton_GetButtonText(id)
	
	if TitanGetVar(TITAN_GEM_BOUTIQUE_ID, "ShowLabelText") then
		visibleGemBoutique = HandleTimer(TITAN_GEM_BOUTIQUE_ID, visibleGemBoutique);
		return '', HandleUpdate(TITAN_GEM_BOUTIQUE_ID, idGemBoutique);	
	else
		visibleGemBoutique = false;
		HandleHide(TITAN_GEM_BOUTIQUE_ID);
		if TitanGetVar(TITAN_GEM_BOUTIQUE_ID, "ShowIcon") then
			return '', '';
		else
			return HIGHLIGHT_FONT_COLOR_CODE .. L["TITAN_GEM_BOUTIQUE_TOOLTIP_TITLE"] .. FONT_COLOR_CODE_CLOSE;
		end		
	end
	
end

-- SetTooltip
function TitanPanelGemBoutiqueButton_GetTooltipText()
	C_Garrison.RequestLandingPageShipmentInfo();
	ScanBuildings();
	return PrepareTooltip(idGemBoutique)
end

-- OnClick
function TitanPanelGemBoutiqueButton_OnClick(self, button)
	HandleClick(button);
end

-- PrepareMenu
function TitanPanelRightClickMenu_PrepareGemBoutiqueMenu()

	TitanPanelRightClickMenu_AddTitle(TitanPlugins[TITAN_GEM_BOUTIQUE_ID].menuText);
	
	TitanPanelRightClickMenu_AddSpacer();

	info = {};
	info.text = L["TITAN_WORK_ORDERS_RIGHT_SIDE"];
	info.func = TitanPanelGemBoutiqueButton_ToggleRightSideDisplay;
	info.checked = TitanGetVar(TITAN_GEM_BOUTIQUE_ID, "DisplayOnRightSide");
	UIDropDownMenu_AddButton(info);
	
	BuildMenu(TITAN_GEM_BOUTIQUE_ID);
	
end

-- ToggleRightSideDisplay
function TitanPanelGemBoutiqueButton_ToggleRightSideDisplay()
	TitanToggleVar(TITAN_GEM_BOUTIQUE_ID, "DisplayOnRightSide");
	TitanPanel_InitPanelButtons();
end



-- === SCRIBES_QUARTERS ===

-- OnLoad
function TitanPanelScribesQuartersButton_OnLoad(self)
	self.registry = {
		id = TITAN_SCRIBES_QUARTERS_ID,
		category = TITAN_WORK_ORDERS_CATEGORY,
		version = TITAN_WORK_ORDERS_VERSION,
		menuText = L["TITAN_SCRIBES_QUARTERS_MENU_TEXT"],
		buttonTextFunction = "TitanPanelScribesQuartersButton_GetButtonText", 
		tooltipTitle = L["TITAN_SCRIBES_QUARTERS_TOOLTIP_TITLE"],
		tooltipTextFunction = "TitanPanelScribesQuartersButton_GetTooltipText",
		icon = TITAN_SCRIBES_QUARTERS_ICON,
		
		iconWidth = 16,
		savedVariables = {        
			ShowIcon = true,
			ShowLabelText = true,
			ShowColoredText = true,
			DisplayOnRightSide = false,
		}
	};     
	self:RegisterEvent("PLAYER_ENTERING_WORLD");
end

-- OnEvent
function TitanPanelScribesQuartersButton_OnEvent(self, event, ...)
	if (event == "PLAYER_ENTERING_WORLD") 
	and ((not self:IsEventRegistered("GARRISON_BUILDING_UPDATE")) 
	or (not self:IsEventRegistered("GARRISON_BUILDING_ACTIVATABLE")) 
	or (not self:IsEventRegistered("GARRISON_BUILDING_ACTIVATED"))
	or (not self:IsEventRegistered("GARRISON_BUILDING_LIST_UPDATE"))) then
		if debugEvents then print('PLAYER_ENTERING_WORLD') end 
		self:RegisterEvent("GARRISON_BUILDING_UPDATE");
		self:RegisterEvent("GARRISON_BUILDING_ACTIVATABLE");
		self:RegisterEvent("GARRISON_BUILDING_ACTIVATED");
		self:RegisterEvent("GARRISON_BUILDING_LIST_UPDATE");
	end	   
	EventHandler(event);
end

-- OnShow
function TitanPanelScribesQuartersButton_OnShow()
	if debugOnShow then print('Titan [Work Orders][OnShow][' .. TITAN_SCRIBES_QUARTERS_ID .. ']: OnShow fired.') end
	visibleScribesQuarters = HandleTimer(TITAN_SCRIBES_QUARTERS_ID, visibleScribesQuarters);
end

-- OnHide
function TitanPanelScribesQuartersButton_OnHide()
	visibleScribesQuarters = false;
	HandleHide(TITAN_SCRIBES_QUARTERS_ID);
end

-- GetButtonText
function TitanPanelScribesQuartersButton_GetButtonText(id)
	
	if TitanGetVar(TITAN_SCRIBES_QUARTERS_ID, "ShowLabelText") then
		visibleScribesQuarters = HandleTimer(TITAN_SCRIBES_QUARTERS_ID, visibleScribesQuarters);
		return '', HandleUpdate(TITAN_SCRIBES_QUARTERS_ID, idScribesQuarters);	
	else
		visibleScribesQuarters = false;
		HandleHide(TITAN_SCRIBES_QUARTERS_ID);
		if TitanGetVar(TITAN_SCRIBES_QUARTERS_ID, "ShowIcon") then
			return '', '';
		else
			return HIGHLIGHT_FONT_COLOR_CODE .. L["TITAN_SCRIBES_QUARTERS_TOOLTIP_TITLE"] .. FONT_COLOR_CODE_CLOSE;
		end		
	end
	
end

-- SetTooltip
function TitanPanelScribesQuartersButton_GetTooltipText()
	C_Garrison.RequestLandingPageShipmentInfo();
	ScanBuildings();
	return PrepareTooltip(idScribesQuarters)
end

-- OnClick
function TitanPanelScribesQuartersButton_OnClick(self, button)
	HandleClick(button);
end

-- PrepareMenu
function TitanPanelRightClickMenu_PrepareScribesQuartersMenu()

	TitanPanelRightClickMenu_AddTitle(TitanPlugins[TITAN_SCRIBES_QUARTERS_ID].menuText);
	
	TitanPanelRightClickMenu_AddSpacer();

	info = {};
	info.text = L["TITAN_WORK_ORDERS_RIGHT_SIDE"];
	info.func = TitanPanelScribesQuartersButton_ToggleRightSideDisplay;
	info.checked = TitanGetVar(TITAN_SCRIBES_QUARTERS_ID, "DisplayOnRightSide");
	UIDropDownMenu_AddButton(info);
	
	BuildMenu(TITAN_SCRIBES_QUARTERS_ID);
	
end

-- ToggleRightSideDisplay
function TitanPanelScribesQuartersButton_ToggleRightSideDisplay()
	TitanToggleVar(TITAN_SCRIBES_QUARTERS_ID, "DisplayOnRightSide");
	TitanPanel_InitPanelButtons();
end



-- === TAILORING_EMPORIUM ===

-- OnLoad
function TitanPanelTailoringEmporiumButton_OnLoad(self)
	self.registry = {
		id = TITAN_TAILORING_EMPORIUM_ID,
		category = TITAN_WORK_ORDERS_CATEGORY,
		version = TITAN_WORK_ORDERS_VERSION,
		menuText = L["TITAN_TAILORING_EMPORIUM_MENU_TEXT"],
		buttonTextFunction = "TitanPanelTailoringEmporiumButton_GetButtonText", 
		tooltipTitle = L["TITAN_TAILORING_EMPORIUM_TOOLTIP_TITLE"],
		tooltipTextFunction = "TitanPanelTailoringEmporiumButton_GetTooltipText",
		icon = TITAN_TAILORING_EMPORIUM_ICON,
		
		iconWidth = 16,
		savedVariables = {        
			ShowIcon = true,
			ShowLabelText = true,
			ShowColoredText = true,
			DisplayOnRightSide = false,
		}
	};     
	self:RegisterEvent("PLAYER_ENTERING_WORLD");
end

-- OnEvent
function TitanPanelTailoringEmporiumButton_OnEvent(self, event, ...)
	if (event == "PLAYER_ENTERING_WORLD") 
	and ((not self:IsEventRegistered("GARRISON_BUILDING_UPDATE")) 
	or (not self:IsEventRegistered("GARRISON_BUILDING_ACTIVATABLE")) 
	or (not self:IsEventRegistered("GARRISON_BUILDING_ACTIVATED"))
	or (not self:IsEventRegistered("GARRISON_BUILDING_LIST_UPDATE"))) then
		if debugEvents then print('PLAYER_ENTERING_WORLD') end 
		self:RegisterEvent("GARRISON_BUILDING_UPDATE");
		self:RegisterEvent("GARRISON_BUILDING_ACTIVATABLE");
		self:RegisterEvent("GARRISON_BUILDING_ACTIVATED");
		self:RegisterEvent("GARRISON_BUILDING_LIST_UPDATE");
	end	   
	EventHandler(event);
end

-- OnShow
function TitanPanelTailoringEmporiumButton_OnShow()
	if debugOnShow then print('Titan [Work Orders][OnShow][' .. TITAN_TAILORING_EMPORIUM_ID .. ']: OnShow fired.') end
	visibleTailoringEmporium = HandleTimer(TITAN_TAILORING_EMPORIUM_ID, visibleTailoringEmporium);
end

-- OnHide
function TitanPanelTailoringEmporiumButton_OnHide()
	visibleTailoringEmporium = false;
	HandleHide(TITAN_TAILORING_EMPORIUM_ID);
end

-- GetButtonText
function TitanPanelTailoringEmporiumButton_GetButtonText(id)
	
	if TitanGetVar(TITAN_TAILORING_EMPORIUM_ID, "ShowLabelText") then
		visibleTailoringEmporium = HandleTimer(TITAN_TAILORING_EMPORIUM_ID, visibleTailoringEmporium);
		return '', HandleUpdate(TITAN_TAILORING_EMPORIUM_ID, idTailoringEmporium);	
	else
		visibleTailoringEmporium = false;
		HandleHide(TITAN_TAILORING_EMPORIUM_ID);
		if TitanGetVar(TITAN_TAILORING_EMPORIUM_ID, "ShowIcon") then
			return '', '';
		else
			return HIGHLIGHT_FONT_COLOR_CODE .. L["TITAN_TAILORING_EMPORIUM_TOOLTIP_TITLE"] .. FONT_COLOR_CODE_CLOSE;
		end		
	end
	
end

-- SetTooltip
function TitanPanelTailoringEmporiumButton_GetTooltipText()
	C_Garrison.RequestLandingPageShipmentInfo();
	ScanBuildings();
	return PrepareTooltip(idTailoringEmporium)
end

-- OnClick
function TitanPanelTailoringEmporiumButton_OnClick(self, button)
	HandleClick(button);
end

-- PrepareMenu
function TitanPanelRightClickMenu_PrepareTailoringEmporiumMenu()

	TitanPanelRightClickMenu_AddTitle(TitanPlugins[TITAN_TAILORING_EMPORIUM_ID].menuText);
	
	TitanPanelRightClickMenu_AddSpacer();

	info = {};
	info.text = L["TITAN_WORK_ORDERS_RIGHT_SIDE"];
	info.func = TitanPanelTailoringEmporiumButton_ToggleRightSideDisplay;
	info.checked = TitanGetVar(TITAN_TAILORING_EMPORIUM_ID, "DisplayOnRightSide");
	UIDropDownMenu_AddButton(info);
	
	BuildMenu(TITAN_TAILORING_EMPORIUM_ID);
	
end

-- ToggleRightSideDisplay
function TitanPanelTailoringEmporiumButton_ToggleRightSideDisplay()
	TitanToggleVar(TITAN_TAILORING_EMPORIUM_ID, "DisplayOnRightSide");
	TitanPanel_InitPanelButtons();
end



-- === THE_FORGE ===

-- OnLoad
function TitanPanelTheForgeButton_OnLoad(self)
	self.registry = {
		id = TITAN_THE_FORGE_ID,
		category = TITAN_WORK_ORDERS_CATEGORY,
		version = TITAN_WORK_ORDERS_VERSION,
		menuText = L["TITAN_THE_FORGE_MENU_TEXT"],
		buttonTextFunction = "TitanPanelTheForgeButton_GetButtonText", 
		tooltipTitle = L["TITAN_THE_FORGE_TOOLTIP_TITLE"],
		tooltipTextFunction = "TitanPanelTheForgeButton_GetTooltipText",
		icon = TITAN_THE_FORGE_ICON,
		
		iconWidth = 16,
		savedVariables = {        
			ShowIcon = true,
			ShowLabelText = true,
			ShowColoredText = true,
			DisplayOnRightSide = false,
		}
	};     
	self:RegisterEvent("PLAYER_ENTERING_WORLD");
end

-- OnEvent
function TitanPanelTheForgeButton_OnEvent(self, event, ...)
	if (event == "PLAYER_ENTERING_WORLD") 
	and ((not self:IsEventRegistered("GARRISON_BUILDING_UPDATE")) 
	or (not self:IsEventRegistered("GARRISON_BUILDING_ACTIVATABLE")) 
	or (not self:IsEventRegistered("GARRISON_BUILDING_ACTIVATED"))
	or (not self:IsEventRegistered("GARRISON_BUILDING_LIST_UPDATE"))) then
		if debugEvents then print('PLAYER_ENTERING_WORLD') end 
		self:RegisterEvent("GARRISON_BUILDING_UPDATE");
		self:RegisterEvent("GARRISON_BUILDING_ACTIVATABLE");
		self:RegisterEvent("GARRISON_BUILDING_ACTIVATED");
		self:RegisterEvent("GARRISON_BUILDING_LIST_UPDATE");
	end	   
	EventHandler(event);
end

-- OnShow
function TitanPanelTheForgeButton_OnShow()
	if debugOnShow then print('Titan [Work Orders][OnShow][' .. TITAN_THE_FORGE_ID .. ']: OnShow fired.') end
	visibleTheForge = HandleTimer(TITAN_THE_FORGE_ID, visibleTheForge);
end

-- OnHide
function TitanPanelTheForgeButton_OnHide()
	visibleTheForge = false;
	HandleHide(TITAN_THE_FORGE_ID);
end

-- GetButtonText
function TitanPanelTheForgeButton_GetButtonText(id)
	
	if TitanGetVar(TITAN_THE_FORGE_ID, "ShowLabelText") then
		visibleTheForge = HandleTimer(TITAN_THE_FORGE_ID, visibleTheForge);
		return '', HandleUpdate(TITAN_THE_FORGE_ID, idTheForge);	
	else
		visibleTheForge = false;
		HandleHide(TITAN_THE_FORGE_ID);
		if TitanGetVar(TITAN_THE_FORGE_ID, "ShowIcon") then
			return '', '';
		else
			return HIGHLIGHT_FONT_COLOR_CODE .. L["TITAN_THE_FORGE_TOOLTIP_TITLE"] .. FONT_COLOR_CODE_CLOSE;
		end		
	end
	
end

-- SetTooltip
function TitanPanelTheForgeButton_GetTooltipText()
	C_Garrison.RequestLandingPageShipmentInfo();
	ScanBuildings();
	return PrepareTooltip(idTheForge)
end

-- OnClick
function TitanPanelTheForgeButton_OnClick(self, button)
	HandleClick(button);
end

-- PrepareMenu
function TitanPanelRightClickMenu_PrepareTheForgeMenu()

	TitanPanelRightClickMenu_AddTitle(TitanPlugins[TITAN_THE_FORGE_ID].menuText);
	
	TitanPanelRightClickMenu_AddSpacer();

	info = {};
	info.text = L["TITAN_WORK_ORDERS_RIGHT_SIDE"];
	info.func = TitanPanelTheForgeButton_ToggleRightSideDisplay;
	info.checked = TitanGetVar(TITAN_THE_FORGE_ID, "DisplayOnRightSide");
	UIDropDownMenu_AddButton(info);
	
	BuildMenu(TITAN_THE_FORGE_ID);
	
end

-- ToggleRightSideDisplay
function TitanPanelTheForgeButton_ToggleRightSideDisplay()
	TitanToggleVar(TITAN_THE_FORGE_ID, "DisplayOnRightSide");
	TitanPanel_InitPanelButtons();
end



-- === BARN ===

-- OnLoad
function TitanPanelBarnButton_OnLoad(self)
	self.registry = {
		id = TITAN_BARN_ID,
		category = TITAN_WORK_ORDERS_CATEGORY,
		version = TITAN_WORK_ORDERS_VERSION,
		menuText = L["TITAN_BARN_MENU_TEXT"],
		buttonTextFunction = "TitanPanelBarnButton_GetButtonText", 
		tooltipTitle = L["TITAN_BARN_TOOLTIP_TITLE"],
		tooltipTextFunction = "TitanPanelBarnButton_GetTooltipText",
		icon = TITAN_BARN_ICON,
		
		iconWidth = 16,
		savedVariables = {        
			ShowIcon = true,
			ShowLabelText = true,
			ShowColoredText = true,
			DisplayOnRightSide = false,
		}
	};     
	self:RegisterEvent("PLAYER_ENTERING_WORLD");
end

-- OnEvent
function TitanPanelBarnButton_OnEvent(self, event, ...)
	if (event == "PLAYER_ENTERING_WORLD") 
	and ((not self:IsEventRegistered("GARRISON_BUILDING_UPDATE")) 
	or (not self:IsEventRegistered("GARRISON_BUILDING_ACTIVATABLE")) 
	or (not self:IsEventRegistered("GARRISON_BUILDING_ACTIVATED"))
	or (not self:IsEventRegistered("GARRISON_BUILDING_LIST_UPDATE"))) then
		if debugEvents then print('PLAYER_ENTERING_WORLD') end 
		self:RegisterEvent("GARRISON_BUILDING_UPDATE");
		self:RegisterEvent("GARRISON_BUILDING_ACTIVATABLE");
		self:RegisterEvent("GARRISON_BUILDING_ACTIVATED");
		self:RegisterEvent("GARRISON_BUILDING_LIST_UPDATE");
	end	   
	EventHandler(event);
end

-- OnShow
function TitanPanelBarnButton_OnShow()
	if debugOnShow then print('Titan [Work Orders][OnShow][' .. TITAN_BARN_ID .. ']: OnShow fired.') end
	visibleBarn = HandleTimer(TITAN_BARN_ID, visibleBarn);
end

-- OnHide
function TitanPanelBarnButton_OnHide()
	visibleBarn = false;
	HandleHide(TITAN_BARN_ID);
end

-- GetButtonText
function TitanPanelBarnButton_GetButtonText(id)
	
	if TitanGetVar(TITAN_BARN_ID, "ShowLabelText") then
		visibleBarn = HandleTimer(TITAN_BARN_ID, visibleBarn);
		return '', HandleUpdate(TITAN_BARN_ID, idBarn);	
	else
		visibleBarn = false;
		HandleHide(TITAN_BARN_ID);
		if TitanGetVar(TITAN_BARN_ID, "ShowIcon") then
			return '', '';
		else
			return HIGHLIGHT_FONT_COLOR_CODE .. L["TITAN_BARN_TOOLTIP_TITLE"] .. FONT_COLOR_CODE_CLOSE;
		end		
	end
	
end

-- SetTooltip
function TitanPanelBarnButton_GetTooltipText()
	C_Garrison.RequestLandingPageShipmentInfo();
	ScanBuildings();
	return PrepareTooltip(idBarn)
end

-- OnClick
function TitanPanelBarnButton_OnClick(self, button)
	HandleClick(button);
end

-- PrepareMenu
function TitanPanelRightClickMenu_PrepareBarnMenu()

	TitanPanelRightClickMenu_AddTitle(TitanPlugins[TITAN_BARN_ID].menuText);
	
	TitanPanelRightClickMenu_AddSpacer();

	info = {};
	info.text = L["TITAN_WORK_ORDERS_RIGHT_SIDE"];
	info.func = TitanPanelBarnButton_ToggleRightSideDisplay;
	info.checked = TitanGetVar(TITAN_BARN_ID, "DisplayOnRightSide");
	UIDropDownMenu_AddButton(info);
	
	BuildMenu(TITAN_BARN_ID);
	
end

-- ToggleRightSideDisplay
function TitanPanelBarnButton_ToggleRightSideDisplay()
	TitanToggleVar(TITAN_BARN_ID, "DisplayOnRightSide");
	TitanPanel_InitPanelButtons();
end



-- === LUMBER_MILL ===

-- OnLoad
function TitanPanelLumberMillButton_OnLoad(self)
	self.registry = {
		id = TITAN_LUMBER_MILL_ID,
		category = TITAN_WORK_ORDERS_CATEGORY,
		version = TITAN_WORK_ORDERS_VERSION,
		menuText = L["TITAN_LUMBER_MILL_MENU_TEXT"],
		buttonTextFunction = "TitanPanelLumberMillButton_GetButtonText", 
		tooltipTitle = L["TITAN_LUMBER_MILL_TOOLTIP_TITLE"],
		tooltipTextFunction = "TitanPanelLumberMillButton_GetTooltipText",
		icon = TITAN_LUMBER_MILL_ICON,
		
		iconWidth = 16,
		savedVariables = {        
			ShowIcon = true,
			ShowLabelText = true,
			ShowColoredText = true,
			DisplayOnRightSide = false,
		}
	};     
	self:RegisterEvent("PLAYER_ENTERING_WORLD");
end

-- OnEvent
function TitanPanelLumberMillButton_OnEvent(self, event, ...)
	if (event == "PLAYER_ENTERING_WORLD") 
	and ((not self:IsEventRegistered("GARRISON_BUILDING_UPDATE")) 
	or (not self:IsEventRegistered("GARRISON_BUILDING_ACTIVATABLE")) 
	or (not self:IsEventRegistered("GARRISON_BUILDING_ACTIVATED"))
	or (not self:IsEventRegistered("GARRISON_BUILDING_LIST_UPDATE"))) then
		if debugEvents then print('PLAYER_ENTERING_WORLD') end 
		self:RegisterEvent("GARRISON_BUILDING_UPDATE");
		self:RegisterEvent("GARRISON_BUILDING_ACTIVATABLE");
		self:RegisterEvent("GARRISON_BUILDING_ACTIVATED");
		self:RegisterEvent("GARRISON_BUILDING_LIST_UPDATE");
	end	   
	EventHandler(event);
end

-- OnShow
function TitanPanelLumberMillButton_OnShow()
	if debugOnShow then print('Titan [Work Orders][OnShow][' .. TITAN_LUMBER_MILL_ID .. ']: OnShow fired.') end
	visibleLumberMill = HandleTimer(TITAN_LUMBER_MILL_ID, visibleLumberMill);
end

-- OnHide
function TitanPanelLumberMillButton_OnHide()
	visibleLumberMill = false;
	HandleHide(TITAN_LUMBER_MILL_ID);
end

-- GetButtonText
function TitanPanelLumberMillButton_GetButtonText(id)
	
	if TitanGetVar(TITAN_LUMBER_MILL_ID, "ShowLabelText") then
		visibleLumberMill = HandleTimer(TITAN_LUMBER_MILL_ID, visibleLumberMill);
		return '', HandleUpdate(TITAN_LUMBER_MILL_ID, idLumberMill);	
	else
		visibleLumberMill = false;
		HandleHide(TITAN_LUMBER_MILL_ID);
		if TitanGetVar(TITAN_LUMBER_MILL_ID, "ShowIcon") then
			return '', '';
		else
			return HIGHLIGHT_FONT_COLOR_CODE .. L["TITAN_LUMBER_MILL_TOOLTIP_TITLE"] .. FONT_COLOR_CODE_CLOSE;
		end		
	end
	
end

-- SetTooltip
function TitanPanelLumberMillButton_GetTooltipText()
	C_Garrison.RequestLandingPageShipmentInfo();
	ScanBuildings();
	return PrepareTooltip(idLumberMill)
end

-- OnClick
function TitanPanelLumberMillButton_OnClick(self, button)
	HandleClick(button);
end

-- PrepareMenu
function TitanPanelRightClickMenu_PrepareLumberMillMenu()

	TitanPanelRightClickMenu_AddTitle(TitanPlugins[TITAN_LUMBER_MILL_ID].menuText);
	
	TitanPanelRightClickMenu_AddSpacer();

	info = {};
	info.text = L["TITAN_WORK_ORDERS_RIGHT_SIDE"];
	info.func = TitanPanelLumberMillButton_ToggleRightSideDisplay;
	info.checked = TitanGetVar(TITAN_LUMBER_MILL_ID, "DisplayOnRightSide");
	UIDropDownMenu_AddButton(info);
	
	BuildMenu(TITAN_LUMBER_MILL_ID);
	
end

-- ToggleRightSideDisplay
function TitanPanelLumberMillButton_ToggleRightSideDisplay()
	TitanToggleVar(TITAN_LUMBER_MILL_ID, "DisplayOnRightSide");
	TitanPanel_InitPanelButtons();
end



-- === TRADING_POST ===

-- OnLoad
function TitanPanelTradingPostButton_OnLoad(self)
	self.registry = {
		id = TITAN_TRADING_POST_ID,
		category = TITAN_WORK_ORDERS_CATEGORY,
		version = TITAN_WORK_ORDERS_VERSION,
		menuText = L["TITAN_TRADING_POST_MENU_TEXT"],
		buttonTextFunction = "TitanPanelTradingPostButton_GetButtonText", 
		tooltipTitle = L["TITAN_TRADING_POST_TOOLTIP_TITLE"],
		tooltipTextFunction = "TitanPanelTradingPostButton_GetTooltipText",
		icon = TITAN_TRADING_POST_ICON,
		
		iconWidth = 16,
		savedVariables = {        
			ShowIcon = true,
			ShowLabelText = true,
			ShowColoredText = true,
			DisplayOnRightSide = false,
		}
	};     
	self:RegisterEvent("PLAYER_ENTERING_WORLD");
end

-- OnEvent
function TitanPanelTradingPostButton_OnEvent(self, event, ...)
	if (event == "PLAYER_ENTERING_WORLD") 
	and ((not self:IsEventRegistered("GARRISON_BUILDING_UPDATE")) 
	or (not self:IsEventRegistered("GARRISON_BUILDING_ACTIVATABLE")) 
	or (not self:IsEventRegistered("GARRISON_BUILDING_ACTIVATED"))
	or (not self:IsEventRegistered("GARRISON_BUILDING_LIST_UPDATE"))) then
		if debugEvents then print('PLAYER_ENTERING_WORLD') end 
		self:RegisterEvent("GARRISON_BUILDING_UPDATE");
		self:RegisterEvent("GARRISON_BUILDING_ACTIVATABLE");
		self:RegisterEvent("GARRISON_BUILDING_ACTIVATED");
		self:RegisterEvent("GARRISON_BUILDING_LIST_UPDATE");
	end	   
	EventHandler(event);
end

-- OnShow
function TitanPanelTradingPostButton_OnShow()
	if debugOnShow then print('Titan [Work Orders][OnShow][' .. TITAN_TRADING_POST_ID .. ']: OnShow fired.') end
	visibleTradingPost = HandleTimer(TITAN_TRADING_POST_ID, visibleTradingPost);
end

-- OnHide
function TitanPanelTradingPostButton_OnHide()
	visibleTradingPost = false;
	HandleHide(TITAN_TRADING_POST_ID);
end

-- GetButtonText
function TitanPanelTradingPostButton_GetButtonText(id)
	
	if TitanGetVar(TITAN_TRADING_POST_ID, "ShowLabelText") then
		visibleTradingPost = HandleTimer(TITAN_TRADING_POST_ID, visibleTradingPost);
		return '', HandleUpdate(TITAN_TRADING_POST_ID, idTradingPost);	
	else
		visibleTradingPost = false;
		HandleHide(TITAN_TRADING_POST_ID);
		if TitanGetVar(TITAN_TRADING_POST_ID, "ShowIcon") then
			return '', '';
		else
			return HIGHLIGHT_FONT_COLOR_CODE .. L["TITAN_TRADING_POST_TOOLTIP_TITLE"] .. FONT_COLOR_CODE_CLOSE;
		end		
	end
	
end

-- SetTooltip
function TitanPanelTradingPostButton_GetTooltipText()
	C_Garrison.RequestLandingPageShipmentInfo();
	ScanBuildings();
	return PrepareTooltip(idTradingPost)
end

-- OnClick
function TitanPanelTradingPostButton_OnClick(self, button)
	HandleClick(button);
end

-- PrepareMenu
function TitanPanelRightClickMenu_PrepareTradingPostMenu()

	TitanPanelRightClickMenu_AddTitle(TitanPlugins[TITAN_TRADING_POST_ID].menuText);
	
	TitanPanelRightClickMenu_AddSpacer();

	info = {};
	info.text = L["TITAN_WORK_ORDERS_RIGHT_SIDE"];
	info.func = TitanPanelTradingPostButton_ToggleRightSideDisplay;
	info.checked = TitanGetVar(TITAN_TRADING_POST_ID, "DisplayOnRightSide");
	UIDropDownMenu_AddButton(info);
	
	BuildMenu(TITAN_TRADING_POST_ID);
	
end

-- ToggleRightSideDisplay
function TitanPanelTradingPostButton_ToggleRightSideDisplay()
	TitanToggleVar(TITAN_TRADING_POST_ID, "DisplayOnRightSide");
	TitanPanel_InitPanelButtons();
end



-- === DWARVEN_BUNKER ===

-- OnLoad
function TitanPanelDwarvenBunkerButton_OnLoad(self)
	self.registry = {
		id = TITAN_DWARVEN_BUNKER_ID,
		category = TITAN_WORK_ORDERS_CATEGORY,
		version = TITAN_WORK_ORDERS_VERSION,
		menuText = L["TITAN_DWARVEN_BUNKER_MENU_TEXT"],
		buttonTextFunction = "TitanPanelDwarvenBunkerButton_GetButtonText", 
		tooltipTitle = L["TITAN_DWARVEN_BUNKER_TOOLTIP_TITLE"],
		tooltipTextFunction = "TitanPanelDwarvenBunkerButton_GetTooltipText",
		icon = TITAN_DWARVEN_BUNKER_ICON,
		
		iconWidth = 16,
		savedVariables = {        
			ShowIcon = true,
			ShowLabelText = true,
			ShowColoredText = true,
			DisplayOnRightSide = false,
		}
	};     
	self:RegisterEvent("PLAYER_ENTERING_WORLD");
end

-- OnEvent
function TitanPanelDwarvenBunkerButton_OnEvent(self, event, ...)
	if (event == "PLAYER_ENTERING_WORLD") 
	and ((not self:IsEventRegistered("GARRISON_BUILDING_UPDATE")) 
	or (not self:IsEventRegistered("GARRISON_BUILDING_ACTIVATABLE")) 
	or (not self:IsEventRegistered("GARRISON_BUILDING_ACTIVATED"))
	or (not self:IsEventRegistered("GARRISON_BUILDING_LIST_UPDATE"))) then
		if debugEvents then print('PLAYER_ENTERING_WORLD') end 
		self:RegisterEvent("GARRISON_BUILDING_UPDATE");
		self:RegisterEvent("GARRISON_BUILDING_ACTIVATABLE");
		self:RegisterEvent("GARRISON_BUILDING_ACTIVATED");
		self:RegisterEvent("GARRISON_BUILDING_LIST_UPDATE");
	end	   
	EventHandler(event);
end

-- OnShow
function TitanPanelDwarvenBunkerButton_OnShow()
	if debugOnShow then print('Titan [Work Orders][OnShow][' .. TITAN_DWARVEN_BUNKER_ID .. ']: OnShow fired.') end
	visibleDwarvenBunker = HandleTimer(TITAN_DWARVEN_BUNKER_ID, visibleDwarvenBunker);
end

-- OnHide
function TitanPanelDwarvenBunkerButton_OnHide()
	visibleDwarvenBunker = false;
	HandleHide(TITAN_DWARVEN_BUNKER_ID);
end

-- GetButtonText
function TitanPanelDwarvenBunkerButton_GetButtonText(id)
	
	if TitanGetVar(TITAN_DWARVEN_BUNKER_ID, "ShowLabelText") then
		visibleDwarvenBunker = HandleTimer(TITAN_DWARVEN_BUNKER_ID, visibleDwarvenBunker);
		return '', HandleUpdate(TITAN_DWARVEN_BUNKER_ID, idDwarvenBunker);	
	else
		visibleDwarvenBunker = false;
		HandleHide(TITAN_DWARVEN_BUNKER_ID);
		if TitanGetVar(TITAN_DWARVEN_BUNKER_ID, "ShowIcon") then
			return '', '';
		else
			return HIGHLIGHT_FONT_COLOR_CODE .. L["TITAN_DWARVEN_BUNKER_TOOLTIP_TITLE"] .. FONT_COLOR_CODE_CLOSE;
		end		
	end
	
end

-- SetTooltip
function TitanPanelDwarvenBunkerButton_GetTooltipText()
	C_Garrison.RequestLandingPageShipmentInfo();
	ScanBuildings();
	return PrepareTooltip(idDwarvenBunker)
end

-- OnClick
function TitanPanelDwarvenBunkerButton_OnClick(self, button)
	HandleClick(button);
end

-- PrepareMenu
function TitanPanelRightClickMenu_PrepareDwarvenBunkerMenu()

	TitanPanelRightClickMenu_AddTitle(TitanPlugins[TITAN_DWARVEN_BUNKER_ID].menuText);
	
	TitanPanelRightClickMenu_AddSpacer();

	info = {};
	info.text = L["TITAN_WORK_ORDERS_RIGHT_SIDE"];
	info.func = TitanPanelDwarvenBunkerButton_ToggleRightSideDisplay;
	info.checked = TitanGetVar(TITAN_DWARVEN_BUNKER_ID, "DisplayOnRightSide");
	UIDropDownMenu_AddButton(info);
	
	BuildMenu(TITAN_DWARVEN_BUNKER_ID);
	
end

-- ToggleRightSideDisplay
function TitanPanelDwarvenBunkerButton_ToggleRightSideDisplay()
	TitanToggleVar(TITAN_DWARVEN_BUNKER_ID, "DisplayOnRightSide");
	TitanPanel_InitPanelButtons();
end



-- === WAR_MILL ===

-- OnLoad
function TitanPanelWarMillButton_OnLoad(self)
	self.registry = {
		id = TITAN_WAR_MILL_ID,
		category = TITAN_WORK_ORDERS_CATEGORY,
		version = TITAN_WORK_ORDERS_VERSION,
		menuText = L["TITAN_WAR_MILL_MENU_TEXT"],
		buttonTextFunction = "TitanPanelWarMillButton_GetButtonText", 
		tooltipTitle = L["TITAN_WAR_MILL_TOOLTIP_TITLE"],
		tooltipTextFunction = "TitanPanelWarMillButton_GetTooltipText",
		icon = TITAN_WAR_MILL_ICON,
		
		iconWidth = 16,
		savedVariables = {        
			ShowIcon = true,
			ShowLabelText = true,
			ShowColoredText = true,
			DisplayOnRightSide = false,
		}
	};     
	self:RegisterEvent("PLAYER_ENTERING_WORLD");
end

-- OnEvent
function TitanPanelWarMillButton_OnEvent(self, event, ...)
	if (event == "PLAYER_ENTERING_WORLD") 
	and ((not self:IsEventRegistered("GARRISON_BUILDING_UPDATE")) 
	or (not self:IsEventRegistered("GARRISON_BUILDING_ACTIVATABLE")) 
	or (not self:IsEventRegistered("GARRISON_BUILDING_ACTIVATED"))
	or (not self:IsEventRegistered("GARRISON_BUILDING_LIST_UPDATE"))) then
		if debugEvents then print('PLAYER_ENTERING_WORLD') end 
		self:RegisterEvent("GARRISON_BUILDING_UPDATE");
		self:RegisterEvent("GARRISON_BUILDING_ACTIVATABLE");
		self:RegisterEvent("GARRISON_BUILDING_ACTIVATED");
		self:RegisterEvent("GARRISON_BUILDING_LIST_UPDATE");
	end	   
	EventHandler(event);
end

-- OnShow
function TitanPanelWarMillButton_OnShow()
	if debugOnShow then print('Titan [Work Orders][OnShow][' .. TITAN_WAR_MILL_ID .. ']: OnShow fired.') end
	visibleWarMill = HandleTimer(TITAN_WAR_MILL_ID, visibleWarMill);
end

-- OnHide
function TitanPanelWarMillButton_OnHide()
	visibleWarMill = false;
	HandleHide(TITAN_WAR_MILL_ID);
end

-- GetButtonText
function TitanPanelWarMillButton_GetButtonText(id)
	
	if TitanGetVar(TITAN_WAR_MILL_ID, "ShowLabelText") then
		visibleWarMill = HandleTimer(TITAN_WAR_MILL_ID, visibleWarMill);
		return '', HandleUpdate(TITAN_WAR_MILL_ID, idWarMill);	
	else
		visibleWarMill = false;
		HandleHide(TITAN_WAR_MILL_ID);
		if TitanGetVar(TITAN_WAR_MILL_ID, "ShowIcon") then
			return '', '';
		else
			return HIGHLIGHT_FONT_COLOR_CODE .. L["TITAN_WAR_MILL_TOOLTIP_TITLE"] .. FONT_COLOR_CODE_CLOSE;
		end		
	end
	
end

-- SetTooltip
function TitanPanelWarMillButton_GetTooltipText()
	C_Garrison.RequestLandingPageShipmentInfo();
	ScanBuildings();
	return PrepareTooltip(idWarMill)
end

-- OnClick
function TitanPanelWarMillButton_OnClick(self, button)
	HandleClick(button);
end

-- PrepareMenu
function TitanPanelRightClickMenu_PrepareWarMillMenu()

	TitanPanelRightClickMenu_AddTitle(TitanPlugins[TITAN_WAR_MILL_ID].menuText);
	
	TitanPanelRightClickMenu_AddSpacer();

	info = {};
	info.text = L["TITAN_WORK_ORDERS_RIGHT_SIDE"];
	info.func = TitanPanelWarMillButton_ToggleRightSideDisplay;
	info.checked = TitanGetVar(TITAN_WAR_MILL_ID, "DisplayOnRightSide");
	UIDropDownMenu_AddButton(info);
	
	BuildMenu(TITAN_WAR_MILL_ID);
	
end

-- ToggleRightSideDisplay
function TitanPanelWarMillButton_ToggleRightSideDisplay()
	TitanToggleVar(TITAN_WAR_MILL_ID, "DisplayOnRightSide");
	TitanPanel_InitPanelButtons();
end



-- === HERB_GARDEN ===

-- OnLoad
function TitanPanelHerbGardenButton_OnLoad(self)
	self.registry = {
		id = TITAN_HERB_GARDEN_ID,
		category = TITAN_WORK_ORDERS_CATEGORY,
		version = TITAN_WORK_ORDERS_VERSION,
		menuText = L["TITAN_HERB_GARDEN_MENU_TEXT"],
		buttonTextFunction = "TitanPanelHerbGardenButton_GetButtonText", 
		tooltipTitle = L["TITAN_HERB_GARDEN_TOOLTIP_TITLE"],
		tooltipTextFunction = "TitanPanelHerbGardenButton_GetTooltipText",
		icon = TITAN_HERB_GARDEN_ICON,
		
		iconWidth = 16,
		savedVariables = {        
			ShowIcon = true,
			ShowLabelText = true,
			ShowColoredText = true,
			DisplayOnRightSide = false,
		}
	};     
	self:RegisterEvent("PLAYER_ENTERING_WORLD");
end

-- OnEvent
function TitanPanelHerbGardenButton_OnEvent(self, event, ...)
	if (event == "PLAYER_ENTERING_WORLD") 
	and ((not self:IsEventRegistered("GARRISON_BUILDING_UPDATE")) 
	or (not self:IsEventRegistered("GARRISON_BUILDING_ACTIVATABLE")) 
	or (not self:IsEventRegistered("GARRISON_BUILDING_ACTIVATED"))
	or (not self:IsEventRegistered("GARRISON_BUILDING_LIST_UPDATE"))) then
		if debugEvents then print('PLAYER_ENTERING_WORLD') end 
		self:RegisterEvent("GARRISON_BUILDING_UPDATE");
		self:RegisterEvent("GARRISON_BUILDING_ACTIVATABLE");
		self:RegisterEvent("GARRISON_BUILDING_ACTIVATED");
		self:RegisterEvent("GARRISON_BUILDING_LIST_UPDATE");
	end	   
	EventHandler(event);
end

-- OnShow
function TitanPanelHerbGardenButton_OnShow()
	if debugOnShow then print('Titan [Work Orders][OnShow][' .. TITAN_HERB_GARDEN_ID .. ']: OnShow fired.') end
	visibleHerbGarden = HandleTimer(TITAN_HERB_GARDEN_ID, visibleHerbGarden);
end

-- OnHide
function TitanPanelHerbGardenButton_OnHide()
	visibleHerbGarden = false;
	HandleHide(TITAN_HERB_GARDEN_ID);
end

-- GetButtonText
function TitanPanelHerbGardenButton_GetButtonText(id)
	
	if TitanGetVar(TITAN_HERB_GARDEN_ID, "ShowLabelText") then
		visibleHerbGarden = HandleTimer(TITAN_HERB_GARDEN_ID, visibleHerbGarden);
		return '', HandleUpdate(TITAN_HERB_GARDEN_ID, idHerbGarden);	
	else
		visibleHerbGarden = false;
		HandleHide(TITAN_HERB_GARDEN_ID);
		if TitanGetVar(TITAN_HERB_GARDEN_ID, "ShowIcon") then
			return '', '';
		else
			return HIGHLIGHT_FONT_COLOR_CODE .. L["TITAN_HERB_GARDEN_TOOLTIP_TITLE"] .. FONT_COLOR_CODE_CLOSE;
		end		
	end
	
end

-- SetTooltip
function TitanPanelHerbGardenButton_GetTooltipText()
	C_Garrison.RequestLandingPageShipmentInfo();
	ScanBuildings();
	return PrepareTooltip(idHerbGarden)
end

-- OnClick
function TitanPanelHerbGardenButton_OnClick(self, button)
	HandleClick(button);
end

-- PrepareMenu
function TitanPanelRightClickMenu_PrepareHerbGardenMenu()

	TitanPanelRightClickMenu_AddTitle(TitanPlugins[TITAN_HERB_GARDEN_ID].menuText);
	
	TitanPanelRightClickMenu_AddSpacer();

	info = {};
	info.text = L["TITAN_WORK_ORDERS_RIGHT_SIDE"];
	info.func = TitanPanelHerbGardenButton_ToggleRightSideDisplay;
	info.checked = TitanGetVar(TITAN_HERB_GARDEN_ID, "DisplayOnRightSide");
	UIDropDownMenu_AddButton(info);
	
	BuildMenu(TITAN_HERB_GARDEN_ID);
	
end

-- ToggleRightSideDisplay
function TitanPanelHerbGardenButton_ToggleRightSideDisplay()
	TitanToggleVar(TITAN_HERB_GARDEN_ID, "DisplayOnRightSide");
	TitanPanel_InitPanelButtons();
end



-- === LUNARFALL_EXCAVATION ===

-- OnLoad
function TitanPanelLunarfallExcavationButton_OnLoad(self)
	self.registry = {
		id = TITAN_LUNARFALL_EXCAVATION_ID,
		category = TITAN_WORK_ORDERS_CATEGORY,
		version = TITAN_WORK_ORDERS_VERSION,
		menuText = L["TITAN_LUNARFALL_EXCAVATION_MENU_TEXT"],
		buttonTextFunction = "TitanPanelLunarfallExcavationButton_GetButtonText", 
		tooltipTitle = L["TITAN_LUNARFALL_EXCAVATION_TOOLTIP_TITLE"],
		tooltipTextFunction = "TitanPanelLunarfallExcavationButton_GetTooltipText",
		icon = TITAN_LUNARFALL_EXCAVATION_ICON,
		
		iconWidth = 16,
		savedVariables = {        
			ShowIcon = true,
			ShowLabelText = true,
			ShowColoredText = true,
			DisplayOnRightSide = false,
		}
	};     
	self:RegisterEvent("PLAYER_ENTERING_WORLD");
end

-- OnEvent
function TitanPanelLunarfallExcavationButton_OnEvent(self, event, ...)
	if (event == "PLAYER_ENTERING_WORLD") 
	and ((not self:IsEventRegistered("GARRISON_BUILDING_UPDATE")) 
	or (not self:IsEventRegistered("GARRISON_BUILDING_ACTIVATABLE")) 
	or (not self:IsEventRegistered("GARRISON_BUILDING_ACTIVATED"))
	or (not self:IsEventRegistered("GARRISON_BUILDING_LIST_UPDATE"))) then
		if debugEvents then print('PLAYER_ENTERING_WORLD') end 
		self:RegisterEvent("GARRISON_BUILDING_UPDATE");
		self:RegisterEvent("GARRISON_BUILDING_ACTIVATABLE");
		self:RegisterEvent("GARRISON_BUILDING_ACTIVATED");
		self:RegisterEvent("GARRISON_BUILDING_LIST_UPDATE");
	end	   
	EventHandler(event);
end

-- OnShow
function TitanPanelLunarfallExcavationButton_OnShow()
	if debugOnShow then print('Titan [Work Orders][OnShow][' .. TITAN_LUNARFALL_EXCAVATION_ID .. ']: OnShow fired.') end
	visibleLunarfallExcavation = HandleTimer(TITAN_LUNARFALL_EXCAVATION_ID, visibleLunarfallExcavation);
end

-- OnHide
function TitanPanelLunarfallExcavationButton_OnHide()
	visibleLunarfallExcavation = false;
	HandleHide(TITAN_LUNARFALL_EXCAVATION_ID);
end

-- GetButtonText
function TitanPanelLunarfallExcavationButton_GetButtonText(id)
	
	if TitanGetVar(TITAN_LUNARFALL_EXCAVATION_ID, "ShowLabelText") then
		visibleLunarfallExcavation = HandleTimer(TITAN_LUNARFALL_EXCAVATION_ID, visibleLunarfallExcavation);
		return '', HandleUpdate(TITAN_LUNARFALL_EXCAVATION_ID, idLunarfallExcavation);	
	else
		visibleLunarfallExcavation = false;
		HandleHide(TITAN_LUNARFALL_EXCAVATION_ID);
		if TitanGetVar(TITAN_LUNARFALL_EXCAVATION_ID, "ShowIcon") then
			return '', '';
		else
			return HIGHLIGHT_FONT_COLOR_CODE .. L["TITAN_LUNARFALL_EXCAVATION_TOOLTIP_TITLE"] .. FONT_COLOR_CODE_CLOSE;
		end		
	end
	
end

-- SetTooltip
function TitanPanelLunarfallExcavationButton_GetTooltipText()
	C_Garrison.RequestLandingPageShipmentInfo();
	ScanBuildings();
	return PrepareTooltip(idLunarfallExcavation)
end

-- OnClick
function TitanPanelLunarfallExcavationButton_OnClick(self, button)
	HandleClick(button);
end

-- PrepareMenu
function TitanPanelRightClickMenu_PrepareLunarfallExcavationMenu()

	TitanPanelRightClickMenu_AddTitle(TitanPlugins[TITAN_LUNARFALL_EXCAVATION_ID].menuText);
	
	TitanPanelRightClickMenu_AddSpacer();

	info = {};
	info.text = L["TITAN_WORK_ORDERS_RIGHT_SIDE"];
	info.func = TitanPanelLunarfallExcavationButton_ToggleRightSideDisplay;
	info.checked = TitanGetVar(TITAN_LUNARFALL_EXCAVATION_ID, "DisplayOnRightSide");
	UIDropDownMenu_AddButton(info);
	
	BuildMenu(TITAN_LUNARFALL_EXCAVATION_ID);
	
end

-- ToggleRightSideDisplay
function TitanPanelLunarfallExcavationButton_ToggleRightSideDisplay()
	TitanToggleVar(TITAN_LUNARFALL_EXCAVATION_ID, "DisplayOnRightSide");
	TitanPanel_InitPanelButtons();
end



-- === FROSTWALL_MINES ===

-- OnLoad
function TitanPanelFrostwallMinesButton_OnLoad(self)
	self.registry = {
		id = TITAN_FROSTWALL_MINES_ID,
		category = TITAN_WORK_ORDERS_CATEGORY,
		version = TITAN_WORK_ORDERS_VERSION,
		menuText = L["TITAN_FROSTWALL_MINES_MENU_TEXT"],
		buttonTextFunction = "TitanPanelFrostwallMinesButton_GetButtonText", 
		tooltipTitle = L["TITAN_FROSTWALL_MINES_TOOLTIP_TITLE"],
		tooltipTextFunction = "TitanPanelFrostwallMinesButton_GetTooltipText",
		icon = TITAN_FROSTWALL_MINES_ICON,
		
		iconWidth = 16,
		savedVariables = {        
			ShowIcon = true,
			ShowLabelText = true,
			ShowColoredText = true,
			DisplayOnRightSide = false,
		}
	};     
	self:RegisterEvent("PLAYER_ENTERING_WORLD");
end

-- OnEvent
function TitanPanelFrostwallMinesButton_OnEvent(self, event, ...)
	if (event == "PLAYER_ENTERING_WORLD") 
	and ((not self:IsEventRegistered("GARRISON_BUILDING_UPDATE")) 
	or (not self:IsEventRegistered("GARRISON_BUILDING_ACTIVATABLE")) 
	or (not self:IsEventRegistered("GARRISON_BUILDING_ACTIVATED"))
	or (not self:IsEventRegistered("GARRISON_BUILDING_LIST_UPDATE"))) then
		if debugEvents then print('PLAYER_ENTERING_WORLD') end 
		self:RegisterEvent("GARRISON_BUILDING_UPDATE");
		self:RegisterEvent("GARRISON_BUILDING_ACTIVATABLE");
		self:RegisterEvent("GARRISON_BUILDING_ACTIVATED");
		self:RegisterEvent("GARRISON_BUILDING_LIST_UPDATE");
	end	   
	EventHandler(event);
end

-- OnShow
function TitanPanelFrostwallMinesButton_OnShow()
	if debugOnShow then print('Titan [Work Orders][OnShow][' .. TITAN_FROSTWALL_MINES_ID .. ']: OnShow fired.') end
	visibleFrostwallMines = HandleTimer(TITAN_FROSTWALL_MINES_ID, visibleFrostwallMines);
end

-- OnHide
function TitanPanelFrostwallMinesButton_OnHide()
	visibleFrostwallMines = false;
	HandleHide(TITAN_FROSTWALL_MINES_ID);
end

-- GetButtonText
function TitanPanelFrostwallMinesButton_GetButtonText(id)
	
	if TitanGetVar(TITAN_FROSTWALL_MINES_ID, "ShowLabelText") then
		visibleFrostwallMines = HandleTimer(TITAN_FROSTWALL_MINES_ID, visibleFrostwallMines);
		return '', HandleUpdate(TITAN_FROSTWALL_MINES_ID, idFrostwallMines);	
	else
		visibleFrostwallMines = false;
		HandleHide(TITAN_FROSTWALL_MINES_ID);
		if TitanGetVar(TITAN_FROSTWALL_MINES_ID, "ShowIcon") then
			return '', '';
		else
			return HIGHLIGHT_FONT_COLOR_CODE .. L["TITAN_FROSTWALL_MINES_TOOLTIP_TITLE"] .. FONT_COLOR_CODE_CLOSE;
		end		
	end
	
end

-- SetTooltip
function TitanPanelFrostwallMinesButton_GetTooltipText()
	C_Garrison.RequestLandingPageShipmentInfo();
	ScanBuildings();
	return PrepareTooltip(idFrostwallMines)
end

-- OnClick
function TitanPanelFrostwallMinesButton_OnClick(self, button)
	HandleClick(button);
end

-- PrepareMenu
function TitanPanelRightClickMenu_PrepareFrostwallMinesMenu()

	TitanPanelRightClickMenu_AddTitle(TitanPlugins[TITAN_FROSTWALL_MINES_ID].menuText);
	
	TitanPanelRightClickMenu_AddSpacer();

	info = {};
	info.text = L["TITAN_WORK_ORDERS_RIGHT_SIDE"];
	info.func = TitanPanelFrostwallMinesButton_ToggleRightSideDisplay;
	info.checked = TitanGetVar(TITAN_FROSTWALL_MINES_ID, "DisplayOnRightSide");
	UIDropDownMenu_AddButton(info);
	
	BuildMenu(TITAN_FROSTWALL_MINES_ID);
	
end

-- ToggleRightSideDisplay
function TitanPanelFrostwallMinesButton_ToggleRightSideDisplay()
	TitanToggleVar(TITAN_FROSTWALL_MINES_ID, "DisplayOnRightSide");
	TitanPanel_InitPanelButtons();
end
